;; THE GARBAGE CAN MODEL




;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; Variables declaration ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
extensions [array]

globals [
          ;; Replacements of agents.
          participants-replaced
          opportunities-replaced
          solutions-replaced
          problems-replaced
          
          ;; Kinds of decision-making and kinds of flights.
          cum-oversights ;; cumulative number of decisions by oversight
          cum-resolutions ;; cumulative number of decisions by resolution
          cum-postponements-without-organization ;; cumulative number of flights by postponement taking place without the intervention of organizations
          cum-postponements-within-organization ;; cumulative number of flights by postponement to opportunities found within the same organization of the participant postponing the problem
          cum-buck-passings-without-organization ;; cumulative number of flights by buck-passing taking place without the intervention of organizations
          cum-buck-passings-within-organization ;; cumulative number of flights by buck-passing taking place within organizations
          
          ;; How many blocked decisions, postponed problems and buck-passed problems per tick.
          cum-blocked-decisions
          blocked-decisions-per-tick
          cum-postponed-problems
          postponed-problems-per-tick
          cum-buck-passed-problems
          buck-passed-problems-per-tick
          
          ;; The counters of meetings with already-met opportunities, solutions and problems.
          meetings-known-opp
          meetings-opp
          percent-known-opp
          meetings-known-sol
          meetings-sol
          percent-known-sol
          meetings-known-pro
          meetings-pro
          percent-known-pro
          
          ;; Oversights and resolutions for organization founders, organization associates and independent participants.
          cum-oversights-founders ;; cumulative number of decisions by oversight made by at least one organization founder
          cum-resolutions-founders ;; cumulative number of decisions by resolution made by at least one organization founder
          ove/res-founders ;; the ratio of the above magnitudes
          cum-oversights-associates ;; cumulative number of decisions by oversight participated by no organization founder and made by at least one organization associate
          cum-resolutions-associates ;; cumulative number of decisions by resolution participated by no organization founder and made by at least one organization associate
          ove/res-associates ;; the ratio of the above magnitudes
          cum-oversights-independents ;; cumulative number of decisions by oversight participated by no organization founder or associate and made by at least one independent participant
          cum-resolutions-independents ;; cumulative number of decisions by resolution participated by no organization founder or associate and made by at least one independent participant
          ove/res-independents ;; the ratio of the above magnitudes
          
          ;; Percentages of organization founders, organization associates and independent participants.
          percent-founders
          cum-percent-founders
          ave-percent-founders
          percent-associates
          cum-percent-associates
          ave-percent-associates
          percent-independents
          cum-percent-independents
          ave-percent-independents
          
          ;; Percentages of organization founders, organization associates, and independent participants making decisions.
          num-founders-oversights
          num-founders-resolutions
          num-associates-oversights
          num-associates-resolutions
          num-independents-oversights
          num-independents-resolutions
          percent-founders-deciding
          cum-percent-founders-deciding
          ave-percent-founders-deciding
          percent-associates-deciding
          cum-percent-associates-deciding
          ave-percent-associates-deciding
          percent-independents-deciding
          cum-percent-independents-deciding
          ave-percent-independents-deciding
          
          ;; The number of independent participants and organizations:
          ;; random: independent participants with random heading
          ;; headed: independent participants with heading 0
          ;; O: organizations created with a decision by oversight
          ;; R: organizations created with a decision by resolution
          ;; S: organizations created with a spin-off.
          random-independents-list
          headed-independents-list
          O-organizations-list
          R-organizations-list
          S-organizations-list
          
          ;; The number of organization founded and dismantled at each step:
          ;; O: created with a decision by oversight
          ;; R: created with a decision by resolution
          ;; S: created with a spin-off.
          O-organizations-dismantled-this-step
          R-organizations-dismantled-this-step
          S-organizations-dismantled-this-step
          ;; Their cumulative values:
          O-organizations-founded
          R-organizations-founded
          S-organizations-founded
          O-organizations-dismantled
          R-organizations-dismantled
          S-organizations-dismantled
          ;; Lists entailing the cumulative numbers of organizations founded and dismantled at each step:
          O-organizations-founded-list
          R-organizations-founded-list
          S-organizations-founded-list
          O-organizations-dismantled-list
          R-organizations-dismantled-list
          S-organizations-dismantled-list
          
          ;; How long organizations live.
          life-O-organizations
          mean-life-O-organizations
          life-R-organizations
          mean-life-R-organizations
          life-S-organizations
          mean-life-S-organizations
          
          ;; The maximum organization size allowed by the size of the world.
          max-organization-size
          ;; Lists of organizations by size.
          O-organization-size-list
          R-organization-size-list
          S-organization-size-list
          ;; The lists of organizations by size over the whole simulation are interesting. At simulation end, they are transformed into distributions of organizations by size.
          cum-O-organization-size-list
          cum-R-organization-size-list
          cum-S-organization-size-list
          
          ;; Growth rates by organization size. A list of lists, each list for a different organization size.
          size-counter
          growth-rate-lists-by-size
          
          ;; Growth rates distribution by organization size. A list of lists, each list for a different organization size.
          growth-rate-counter
          growth-rate-distribution-lists-by-size
          
          ;; These lists collect the number of would-be-associates and the number of participants who are actually associated, irrespectively of organization size.
          ;; The distributions of organizations per number of would-be associates and actual associates are computed on these data.
          would-be-associates-list
          this-step-associated-list
          
          ;; Lists of life lengths and survivors at simulation end.
          O-mortality-list
          R-mortality-list
          S-mortality-list
          O-survivors-list
          R-survivors-list
          S-survivors-list
        ]

;; A variable common to all agents.
turtles-own [blocked?]
            
;; Our four classes of agents.
breed [solution]
breed [opportunity]
breed [participant]
breed [problem]

;; Their variables.
participant-own [;; These variables are used by all participants.
                 ability
                 charged?
                 with-problem
                 encountered
                 ;; These variables are only used by participants who are also organization members.
                 organization
                 owns-solution
                 owns-efficiency
                 ;; These variables, as well as the in-built variable 'label', are only used by organization founders.
                 ;; The 'label' is here used to identify organizations that have been created with a decision by oversight, a decision by resolution, or a spin-off.
                 date-of-founding  ; at which step the organization was created
                 organization-size  ; the number of organization members, including its founder
                 myterritory  ; the patches where the organization extends
                 would-be-associates  ; the list of participants eligible for association at this step
                 this-step-associated  ; the number of participants who actually associated at this step
                 steps-idle  ; the number of steps the organization made no decision
                 ;; These variables are only used by organization associates.
                 mysupervisor  ; who is my supervisor
                 myboss  ; does not coincide with 'mysupervisor' from the third tier downwards
                ]
opportunity-own [charged?
                 with-problem
                ]
solution-own [efficiency
              owned?
              by-participant
             ] 
problem-own [difficulty
             postponed?
             to-opportunity
             passed?
             to-participant
            ]
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;







;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;; What is done when the "Setup" button is pressed ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to setup 
  clear-all
  
  ;; The label of patches is employed to record which organization is upon it. By exploiting this label, organization founders can know their territory. It is set to black in order to make it invisible.
  ask patches
    [set plabel-color black]
  
  ;;; WARNING: IT MAKES NO SENSE TO REPLACE AN AGENT THAT IS NOT ALLOWED TO EXIT
  ;;; WARNING: IT MAKES NO SENSE TO SPIN-OFF IF ORGANIZATIONS ARE NOT ALLOWED TO FORM
  ;;; WARNING: IT MAKES NO SENSE TO KILL IDLE ORGANIZATIONS IF ORGANIZATIONS ARE NOT ALLOWED TO FORM

  if (replace-participants? and not participants-exit?)
    [print "WARNING: 'replace-participants?' IS NOT EFFECTIVE IF 'participants-exit?' IS NOT ENABLED"]
  if (replace-opportunities? and not opportunities-exit?)
    [print "WARNING: 'replace-opportunities?' IS NOT EFFECTIVE IF 'opportunities-exit?' IS NOT ENABLED"]
  if (replace-solutions? and not (solutions-exit? or spin-off?))
    [print "WARNING: 'replace-solutions?' IS NOT EFFECTIVE UNLESS EITHER 'solutions-exit?' OR 'spin-off?' ARE ENABLED"]
  if (replace-problems? and not problems-exit?)
    [print "WARNING: 'replace-problems?' IS NOT EFFECTIVE IF 'problems-exit?' IS NOT ENABLED"]
  if (spin-off? and not form-organizations?)
    [print "WARNING: 'spin-off?' IS NOT EFFECTIVE IF 'form-organizations?' IS NOT ENABLED"]
  if (max-idle > 0 and not form-organizations?)
    [print "WARNING: 'max-idle > 0' IS NOT EFFECTIVE IF 'form-organizations?' IS NOT ENABLED"]


  
  ;; Initializes the counters of agents' replacements.
  ifelse (participants-exit?)
    [set participants-replaced 0]
    [set participants-replaced "N/A"]
  ifelse (opportunities-exit?)
    [set opportunities-replaced 0]
    [set opportunities-replaced "N/A"]
  ifelse (solutions-exit? or spin-off?)
    [set solutions-replaced 0]
    [set solutions-replaced "N/A"]
  ifelse (problems-exit?)
    [set problems-replaced 0]
    [set problems-replaced "N/A"]
  
  ;; Initializes the counters of the meetings with opportunities, solutions and problems that had already been met.
  set meetings-known-opp 0
  set meetings-opp 0
  set percent-known-opp 0
  set meetings-known-sol 0
  set meetings-sol 0
  ifelse form-organizations?
    [set percent-known-sol "N/A"]
    [set percent-known-sol 0]
  set meetings-known-pro 0
  set meetings-pro 0
  set percent-known-pro 0
  
  ;; Initializes the number of kinds of decision-making and flights.
  set cum-oversights 0
  set cum-resolutions 0
  set cum-postponements-without-organization 0
  set cum-postponements-within-organization 0
  set cum-buck-passings-without-organization 0
  set cum-buck-passings-within-organization 0

  ;; Initializes the kinds of decision-making by all involved participants, by status.
  set cum-oversights-founders 0
  set cum-resolutions-founders 0
  set ove/res-founders "N/A"
  set cum-oversights-associates 0
  set cum-resolutions-associates 0
  set ove/res-associates "N/A"
  set cum-oversights-independents 0
  set cum-resolutions-independents 0
  set ove/res-independents "N/A"

  ;; Initializes the counters of the number of blocked decisions, postponed problems and buck-passed problems.
  set cum-blocked-decisions 0
  set cum-postponed-problems 0
  set cum-buck-passed-problems 0
  
  ;; Initializes the cumulative percentages of organization founders, organization associates, and independent participants.
  set cum-percent-founders 0
  set cum-percent-associates 0
  set cum-percent-independents 0
          
  ;; Initializes the cumulative percentages of organization founders, organization associates, and independent participants making decisions.
  set cum-percent-founders-deciding 0
  set cum-percent-associates-deciding 0
  set cum-percent-independents-deciding 0
  
  ;; Initializes the counters of organizations and independent participants.
  set random-independents-list []
  set headed-independents-list []
  set O-organizations-list []
  set R-organizations-list []
  set S-organizations-list []
          
  ;; Initializes the number of organizations founded and dismantled: the cumulative number, the number at each step, and the lists of numbers at each step..
  set O-organizations-founded 0
  set R-organizations-founded 0
  set S-organizations-founded 0
  set O-organizations-dismantled 0
  set R-organizations-dismantled 0
  set S-organizations-dismantled 0
  set O-organizations-dismantled-this-step 0
  set R-organizations-dismantled-this-step 0
  set S-organizations-dismantled-this-step 0
  set O-organizations-founded-list []
  set R-organizations-founded-list []
  set S-organizations-founded-list []
  set O-organizations-dismantled-list []
  set R-organizations-dismantled-list []
  set S-organizations-dismantled-list []
  
  ;; Initializes the counters of cumulative life of organizations.
  set life-O-organizations 0
  set mean-life-O-organizations "N/A"
  set life-R-organizations 0
  set mean-life-R-organizations "N/A"
  set life-S-organizations 0
  set mean-life-S-organizations "N/A"
  
  ;; Initializes the lists of the data on the distribution of organization size.
  set cum-O-organization-size-list []
  set cum-R-organization-size-list []
  set cum-S-organization-size-list []
  
  ;; Computes the maximum organization size.
  let previous-max-organization-size 0
  let hierarchical-level 0
  ;; Iterates until either the lowest hierarchical level becomes wider than the world, or the number of hierarchical levels becomes higher than the world.
  while [((span-of-control - 1) * max-organization-size + 1) / span-of-control < world-width and hierarchical-level < world-height] [
    set previous-max-organization-size max-organization-size
    set max-organization-size max-organization-size + span-of-control ^ hierarchical-level
    set hierarchical-level hierarchical-level + 1
  ]
  set max-organization-size previous-max-organization-size
  
  ;; Initializes the list of lists of growth rates by organization size.
  set growth-rate-lists-by-size []
  repeat max-organization-size
    [set growth-rate-lists-by-size fput [] growth-rate-lists-by-size]
  
  ;; Initializes the list of lists with the distributions of growth rates. Each list entails the growth rate distribution for a different organization size.
  set growth-rate-distribution-lists-by-size []
  repeat max-organization-size
    [set growth-rate-distribution-lists-by-size fput [] growth-rate-distribution-lists-by-size]
    
  ;; Initializes the list of would-be-associates and the list of those who actually associated.
  set would-be-associates-list []
  set this-step-associated-list []
               
  ;; Initializes the lists of life lengths and survivors.
  set O-mortality-list []
  set R-mortality-list []
  set S-mortality-list []
  set O-survivors-list []
  set R-survivors-list []
  set S-survivors-list []
  
  ;; creates the agents that are initially present in the organization. Heading should be different from zero.
  set-default-shape participant "participant"
  create-participant initial-participants  ;; creates the participants and initializes their variables
  [ 
    setxy random world-width random world-height
    set color yellow
    set heading (1 + random 359)
    set ability random-float (max-ability - min-ability) + min-ability 
    set blocked? false
    set charged? false
    set with-problem nobody
    set encountered []
    set organization -1
    set owns-solution nobody
    set owns-efficiency -1
    set label ""
    set date-of-founding -1
    set organization-size 0
    set myterritory []
    set would-be-associates []
    set this-step-associated 0
    set steps-idle -1
    set mysupervisor nobody
    set myboss nobody
  ]
  set-default-shape opportunity "opportunity"
  create-opportunity initial-opportunities  ;; creates the choice opportunities and initializes their variables
  [ 
    setxy random world-width random world-height
    set color orange
    set blocked? false
    set charged? false
    set with-problem nobody
  ]
  set-default-shape solution "solution"
  create-solution initial-solutions  ;; creates the solutions and initializes their variables
  [ 
    setxy random world-width random world-height
    set color red
    set blocked? false
    set owned? false
    set by-participant nobody
    set efficiency random-float (max-efficiency - min-efficiency) + min-efficiency 
  ]
  set-default-shape problem "problem"
  create-problem initial-problems  ;; creates the problems and initializes their variables
  [ 
    setxy random world-width random world-height
    set color violet
    set blocked? false
    set postponed? false
    set to-opportunity nobody
    set passed? false
    set to-participant nobody
    set difficulty random-float (max-difficulty - min-difficulty) + min-difficulty 
  ]

  reset-ticks
end
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;












;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; What is done when the "Go Step" button is pressed and what is repeated at each step when the "Go Until" button is pressed
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to go


;;; THE SIMULATION IS NOT ALLOWED TO BEGIN IF MINIMUM VALUES OF ABILITY, EFFICIENCY AND DIFFICULTY ARE GREATER THAN THE CORRESPONDING MAXIMUM VALUES
;;; IF ORGANIZATIONS ARE ALLOWED TO FORM, PARTICIPANTS AND SOLUTIONS CANNOT EXIT THE ORGANIZATION

  if (min-ability > max-ability) [
    print "MINIMUM ABILITY SHOULD NOT BE GREATER THAN MAXIMUM ABILITY"
    stop
  ]
  if (min-efficiency > max-efficiency) [
    print "MINIMUM EFFICIENCY SHOULD NOT BE GREATER THAN MAXIMUM EFFICIENCY"
    stop
  ]
  if (min-difficulty > max-difficulty) [
    print "MINIMUM DIFFICULTY SHOULD NOT BE GREATER THAN MAXIMUM DIFFICULTY"
    stop
  ]

  if (form-organizations? and participants-exit?) [
    print "PARTICIPANTS CANNOT BE ALLOWED TO EXIT IF ORGANIZATIONS FORM"
    stop
  ]
  if (form-organizations? and solutions-exit?) [
    print "SOLUTIONS CANNOT BE ALLOWED TO EXIT IF ORGANIZATIONS FORM"
    stop
  ]








;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; DECISION - MAKING

  ;; Though decisions are made by participants, it is more convenient to let patches operate.
  ask patches [
    ;; Resets on black the patches where a decision was made.
    if (pcolor = lime or pcolor = sky)
      [set pcolor black]
    ;; If there is at least one choice opportunity and one organization associate, or one choice opportunity, an independent participant and one solution, then something is done.
    if (any? opportunity-here and ((any? participant-here with [color = gray or color = magenta]) or (any? participant-here with [color = yellow] and any? solution-here))) [
      ;; Flights end where either a decision is made or a decision process is blocked.
      ask participant-here [
        if (charged?) [
          set charged? false
          set with-problem nobody
        ]
      ]
      ask opportunity-here [
        if (charged?) [
          set charged? false
          set with-problem nobody
        ]
      ]
      if (any? problem-here) [
        ask problem-here [
          if (postponed?) [
            set postponed? false
            set to-opportunity nobody
          ]
          if (passed?) [
            set passed? false
            set to-participant nobody
          ]
        ]
      ]
      ;; If there are problems as well, either they are resolved if their ability is sufficient or all agents stay put until another opportunity or another participant passes by and takes a problem away.
      ifelse (any? problem-here) [
        ;; Available efficiency is the maximum one if only independent participants are there. If there are organization members, the available efficiency is the one of the most able participant.      
        let available-efficiency -1
        ifelse (any? participant-here with [color = gray or color = magenta])
          [set available-efficiency [owns-efficiency] of max-one-of (participant-here with [color = gray or color = magenta]) [ability]]
          [set available-efficiency [efficiency] of max-one-of solution-here [efficiency]]
        ;; Available ability is the sum of the abilities of participants on this patch, plus eventually the abilities of the other members of their organizations.
        let available-ability (sum [ability] of participant-here)
        ask participant-here with [color = gray or color = magenta] [
          ask other participant with [organization = [organization] of myself] [
            set available-ability available-ability + ability
          ]
        ]
        ;; If the available ability, multiplied by the available efficiency, is greater or equal than the sum of the difficulty of all problems on the same patch, then decisions are made by resolution.
        ifelse (available-ability * available-efficiency >= (sum [difficulty] of problem-here)) [
          ;; Counts the number of resolutions, the number of resolutions by status of participants, and the number of resolutions per participant distinguished by status.
          set cum-resolutions cum-resolutions + 1
          ifelse (any? participant-here with [color = gray and owns-solution != nobody]) [
            set cum-resolutions-founders cum-resolutions-founders + 1
          ][
            ifelse (any? participant-here with [color = magenta or color = gray and owns-solution = nobody]) [
              set cum-resolutions-associates cum-resolutions-associates + 1
            ][
              if (any? participant-here with [color = yellow])
                [set cum-resolutions-independents cum-resolutions-independents + 1]
            ]
          ]
          ;; Counts the number of participants involved in resolutions.
          set num-founders-resolutions count participant-here with [color = gray and owns-solution != nobody]
          set num-associates-resolutions count participant-here with [color = magenta or color = gray and owns-solution = nobody]
          set num-independents-resolutions count participant-here with [color = yellow]
          ;; A decision by resolution is marked by a green square.
          set pcolor lime
          ;; Learning takes place if spinning-off is allowed.
          if (spin-off?) [
            ask participant-here
              [set ability ability + sum [difficulty] of problem-here]
          ]
          ;; If an organization was involved, its founder records that a decision was made.
          if (any? participant-here with [color = gray or color = magenta]) [
            let this-organization [organization] of one-of participant-here with [color = gray or color = magenta]
            ask participant with [color = gray and owns-solution != nobody and organization = this-organization]
              [set steps-idle 0]
          ]
          ;; If organizations are allowed and no organization was involved, then an organization is created. If no organization exists, whichever independent participants can found and organization. Otherwise, only participants with heading=0 can.
          if (form-organizations? and (not any? participant with [color = gray] or (not any? participant-here with [color = gray or color = magenta] and any? participant-here with [color = yellow and heading = 0]))) [
            let founder nobody
            ifelse (not any? participant with [color = gray])
              [set founder max-one-of participant-here [ability]]
              [set founder max-one-of participant-here with [heading = 0] [ability]]
            let its-solution max-one-of solution-here [efficiency]
            ask founder [
              set blocked? true
              set heading 0
              set color gray
              set organization who
              set myterritory fput patch-here myterritory
              ask patch-here
                [set plabel [organization] of myself]
              set label "R"
              set date-of-founding ticks
              set steps-idle 0
              set owns-solution its-solution
              set owns-efficiency [efficiency] of its-solution
            ]
            ask its-solution [
              set blocked? true
              set owned? true
              set by-participant founder
            ]
          ]
          ;; Eventually, the participants involved in this decision exit.
          ifelse (not form-organizations? and participants-exit?) [
            kill participant-here
          ][
            ;; Otherwise, the participants involved are set free to move if they are not members of organizations.
            ask participant-here with [color = yellow] [
              set blocked? false
            ]
          ]
          ;; The opportunities charged with problems are set free to move.
          ask opportunity-here [
            set blocked? false                
          ]
          ;; Eventually, one of them exits.
          if (opportunities-exit?)
            [kill one-of opportunity-here]
          ;; Unless they are owned by an organization, the solutions involved in this decision are set free to move.
          ask solution-here with [not owned?]
            [set blocked? false]
          ;; Eventually, the solution used in this decision exits. This makes sense only if organizations do not exist.
          if (not form-organizations? and solutions-exit?)
            [kill max-one-of solution-here [efficiency]]
          ;; Eventually, the problems involved in this decision exit.
          ifelse (problems-exit?) [
            kill problem-here
          ][
            ;; Otherwise, the problems involved in this decision are set free to move.
            ask problem-here
              [set blocked? false]
          ]
        ]
        ;; If the ability of the participants is not sufficient to make a decision, all agents on the patch are blocked until either an
        ;; opportunity or a participant arrives, that takes away the most difficult problem.
        ;; If a participant involved is a member of an organization, the whole organization is blocked.
        [
          ; Only agents on this patch need to be impaired to move. Organization members do not move in any case.
          ask turtles-here
            [set blocked? true]
          ;; A blocked decision process is marked by a white square.
          set pcolor white
          ;; A flight by postponement is considered.
          ;; If there are not sufficiently many opportunities and an organization member is involved, he seeks for an opportunity within the organization.
          let xhere pxcor
          let yhere pycor
          let opportunity-found-in-organization? false
          if (postpone? and count opportunity-here <= 1 and any? participant-here with [color = gray or color = magenta]) [
            ask participant-here with [color = gray or color = magenta] [
              let this-organization organization
              if (any? other participant with [organization = this-organization]) [
                ask other participant with [organization = this-organization] [
                  if (any? opportunity-here with [not blocked? and not charged?]) [
                    ask opportunity-here with [not blocked? and not charged?] [
                      move-to patch xhere yhere
                      set opportunity-found-in-organization? true
                    ]
                  ]
                ]
              ]
            ]
          ]
          ;; Eventually, a flight by postponement takes place.
          ;; A flight by postponement takes place by attaching the most difficult problem to a randomly chosen opportunity.
          ifelse (postpone? and count opportunity-here > 1) [
            ;; It records whether this flight was made possible by an opportunity found in an organization, or it occurred independently of organizations.
            ifelse (opportunity-found-in-organization?)
              [set cum-postponements-within-organization cum-postponements-within-organization + 1]
              [set cum-postponements-without-organization cum-postponements-without-organization + 1]
            ;; An opportunity and a problem are paired to one another and set free to move.
            let which-opportunity one-of opportunity-here
            let which-problem-for-opportunity max-one-of problem-here [difficulty]
            ;; The chosen opportunity is charged with the chosen problem.
            ask which-opportunity [
              set blocked? false
              set charged? true
              set with-problem which-problem-for-opportunity
            ]
            ;; The chosen problem is attached to the chosen opportunity.
            ask which-problem-for-opportunity [
              set blocked? false
              set postponed? true
              set to-opportunity which-opportunity            
            ]
          ]
          ;; After the possibility of a flight by postponement, the possibility of a flight by buck-passing is considered.
          ;; A flight by buck-passing takes place by attaching the most difficult problem to the least able participant.
          [
            ;; Eventually, a flight by buck-passing takes place. The buck is preferably passed to a free participant or, if none is available, to an organization member.
            if (passbuck?) [
              ;; A participant must be found, to whom a problem can be passed.
              let found-participant? false
              ;; The least able available participant is selected.
              let which-participant nobody
              ;; Two possibilities are considered: the buck is passed to an independent participant or, if none is there but an organization member isthere, to another member of the organization.
              ;; Choice of participant in the case an independent participant is there.
              if (any? participant-here with [color = yellow] and count participant-here > 1) [
                set cum-buck-passings-without-organization cum-buck-passings-without-organization + 1
                set which-participant min-one-of (participant-here with [color = yellow]) [ability]
                set found-participant? true
              ]
              ;; Choice of participant in the case no independent participant is there, but a organization member is there.
              if (not any? participant-here with [color = yellow] and any? participant-here with [color = gray or color = magenta]) [
                ask one-of participant-here with [color = gray or color = magenta] [
                  let this-organization organization
                  if (count other participant with [organization = this-organization] > 0) [
                    set cum-buck-passings-within-organization cum-buck-passings-within-organization + 1
                    set which-participant min-one-of other participant with [organization = this-organization] [ability]
                    set found-participant? true
                  ]
                ]
              ]
              ;; If a suitable participant has been found, a problem is passed to him.
              if (found-participant?) [
                ;; A problem is selected.
                let which-problem-for-participant max-one-of problem-here [difficulty]    
                ;; The chosen participant is charged with the chosen problem.
                ask which-participant [
                  if (color = yellow)
                    [set blocked? false]
                  set charged? true
                  set with-problem which-problem-for-participant
                ]
                ;; The chosen problem is attached to the chosen participant.
                ;; If the chosen problem was already attached to an opportunity or a participant, it is liberated. Its previous masters are alerted.
                ask which-problem-for-participant [
                  set blocked? false
                  set passed? true
                  set to-participant which-participant
                ]
              ]
            ]
          ]
        ]
      ]
      ;; On the contrary, if there are no problems to be solved, decisions are made by oversight. If there are several participants, 
      ;; several solutions and several opportunities on the same patch, all participants and all solutions make a decision exploiting
      ;; only one opportunity and making use of only one solution. If these agents exit after making a decision, all participants on the
      ;; patch exit, but only one randomly chosen solution exits and only one randomly chosen opportunity exits.
      [
        ;; Counts the number of oversights, the number of oversights by status of participants, and the number of oversights per participant distinguished by status.
        set cum-oversights cum-oversights + 1
        ifelse (any? participant-here with [color = gray and owns-solution != nobody]) [
          set cum-oversights-founders cum-oversights-founders + 1
        ][
          ifelse (any? participant-here with [color = magenta or color = gray and owns-solution = nobody]) [
            set cum-oversights-associates cum-oversights-associates + 1
          ][
            if (any? participant-here with [color = yellow])
              [set cum-oversights-independents cum-oversights-independents + 1]
          ]
        ]
        ;; Counts the number of participants involved in oversights.
        set num-independents-oversights count participant-here with [color = yellow]
        set num-founders-oversights count participant-here with [color = gray and owns-solution != nobody]
        set num-associates-oversights count participant-here with [color = magenta or color = gray and owns-solution = nobody]
        ;; A decision by oversight is marked by a sky-blue square.
        set pcolor sky
        ;; If an organization was involved, its founder records that a decision was made.
        if (any? participant-here with [color = gray or color = magenta]) [
          let this-organization [organization] of one-of participant-here with [color = gray or color = magenta]
          ask participant with [color = gray and owns-solution != nobody and organization = this-organization]
            [set steps-idle 0]
        ]
        ;; If organizations are allowed and no organization was involved, then an organization is created. If no organization exists, whichever independent participants can found and organization. Otherwise, only participants with heading=0 can.
        if (form-organizations? and (not any? participant with [color = gray] or (not any? participant-here with [color = gray or color = magenta] and any? participant-here with [color = yellow and heading = 0]))) [
          let founder nobody
          ifelse (not any? participant with [color = gray])
            [set founder max-one-of participant-here [ability]]
            [set founder max-one-of participant-here with [heading = 0] [ability]]
          let its-solution max-one-of solution-here [efficiency]
          ask founder [
            set blocked? true
            set heading 0
            set color gray
            set organization who
            set myterritory fput patch-here myterritory
            ask patch-here
              [set plabel [organization] of myself]
            set label "O"
            set date-of-founding ticks
            set steps-idle 0
            set owns-solution its-solution
            set owns-efficiency [efficiency] of its-solution
          ]
          ask its-solution [
            set blocked? true
            set owned? true
            set by-participant founder
          ]
        ]
        ;; Eventually, the participants involved in this decision exit.
        ifelse (not form-organizations? and participants-exit?) [
          kill participant-here
        ][
          ;; The participants involved in this decision who are not members of organizations are set free to move.
          ask participant-here with [color = yellow]
            [set blocked? false]
        ]
        ;; The opportunities involved in this decision are set free to move.
        ask opportunity-here
          [set blocked? false]
        ;; Eventually, one of them exits.
        if (opportunities-exit?)
          [kill one-of opportunity-here]
        ;; Unless they are owned by an organization, the solutions involved in this decision are set free to move.
        ask solution-here with [not owned?]
          [set blocked? false]
        ;; Eventually, the solution used in this decision exits. This makes sense only if organizations do not exist.
        if (not form-organizations? and solutions-exit?)
          [kill max-one-of solution-here [efficiency]]
      ]
    ]
  ]











  ;;;;;;;;;;;;;;;;;;;;;;;;;; AND FINALLY MOVE
  
  ;; Organization founders eventually attract independent uncharged participants who happened to be on their patch.
  ask participant with [color = gray and owns-solution != nobody] [
    ;; Makes a list of independent participants who happen to touch organization members in order to ask each of them to enter the organization. So the number of would-be associates is proportional to organization size.
    set myterritory remove-duplicates myterritory
    set would-be-associates sort (participant-on patch-set myterritory) with [color = yellow and not blocked? and not charged?]
    ;; The number of would-be associates is also proportional to the founder's efficiency, so heterogeneity of efficiency causes heterogeneity of growth rates.
    set would-be-associates n-of (min list (length would-be-associates) (int (owns-efficiency * efficiency-growth-factor))) would-be-associates
    ;; Communicates the number of would-be associates to a list for statistical purposes.
    set would-be-associates-list fput (length would-be-associates) would-be-associates-list
    foreach would-be-associates [
      ;; The list 'would-be-associates' may be emptied by a participant making autonomous decisions.
      if (empty? would-be-associates = false) [
        ask ? [
          ;; Remember who is the boss. Go to the place where the boss is. Make the identity of this organization available througout this section.
          set myboss myself
          setxy [xcor] of myboss [ycor] of myboss
          let thisorganization [organization] of myboss
          ;; Looks for a new place in the tree below the founder, whose slope is the span of control.
          let previous-zero-point [xcor] of myboss - 1  ;; the x-coordinate left of the first position of the previous hierarchical level
          let zero-point [xcor] of myboss - 1  ;; the x-coordinate left of the first position of the current hierarchical level
          let x-destination "not-found"  ;; the x-coordinate of the final destination
          let y-destination "not-found"  ;; the y-coordinate of the final destination
          let depth 0  ;; the current hierarchical level, measured top-down
          let width 1  ;; the number of positions at the current hierarchical level
          ;; Repeats the cycle descending the tree until a suitable destination is found.
          while [x-destination = "not-found" and y-destination = "not-found"][
            set depth depth + 1
            set width span-of-control ^ depth
            ;; If it explored the tree up to reaching its head from above, or if the next hierarchical level is larger than the world width, it exits the loop.
            ifelse (width > world-width or depth > world-height) [
              set x-destination "not-exists"
              set y-destination "not-exists"
            ][
              ;; Before scanning this hierarchical level, it records (1) the x-coordinate of the patch just left of it, and (2) its rightmost x-coordinate.
              set previous-zero-point zero-point
              set zero-point [xcor] of myboss + int (width / 2) - width
              let end-point [xcor] of myboss + int (width / 2)
              ;; The expansion-range' is the set of patches where the organization is expanding.
              let expansion-range no-patches
              ifelse (x-wrap(zero-point) <= x-wrap(end-point))
                [set expansion-range patches with [pycor = y-wrap([ycor] of myself - depth) and pxcor > x-wrap(zero-point) and pxcor <= x-wrap(end-point)]]
                [set expansion-range patches with [pycor = y-wrap([ycor] of myself - depth) and (pxcor <= x-wrap(end-point) or pxcor > x-wrap(zero-point))]]
              ;; Scans this hierarchical level looking for a free position. Note that other organizations may impair expansion if they happen to be on the tree.
              foreach sort expansion-range [
                ask ? [
                  ;; If either a destination is found, or it becomes clear that no destination exists, the remaining patches in the expansion range are ignored.
                  if (x-destination = "not-found" and y-destination = "not-found") [
                    ifelse (not any? participant-here with [color = gray or color = magenta]) [
                      set x-destination pxcor
                      set y-destination pycor
                    ][
                     ;; Other organizations may impair the growth of this organization. The previous expansion range surely entails members of my organization.
                     if (any? participant-here with [(color = gray or color = magenta) and organization != thisorganization]) [
                       set x-destination "not-exists"
                       set y-destination "not-exists"
                     ]        
                    ]
                  ]
                ]
              ]
            ]
          ]
          ;; If a suitable destination was found, a new member enters the organization.
          ifelse (x-destination != "not-exists" and y-destination != "not-exists") [
            ;; It records the identity of its supervisor. The 'zero-point'-s are used here.
            ;; The distance between the zero-point and the position where the associate will be placed. Wrapping must be undone in order to compute it.
            let delta x-destination - zero-point
            if (delta < 0)
              [set delta x-destination + world-width - zero-point]
            if (delta >= world-width)
              [set delta x-destination - world-width - zero-point]
            ;; Condition "other" is necessary because, at the first step, the new associate would take itself as supervisor. Conditions on color and being blocked are necessary in order to avoid that randomly walking participants are taken as supervisors.
            set mysupervisor one-of (other participant-on patch x-wrap(previous-zero-point + ceiling (delta / span-of-control)) y-wrap(y-destination + 1)) with [blocked? and (color = gray or color = magenta)]
            ;; If the would-be associate follows its supervisor, and if the supervisor followed as well, the would-be associate enters the organization as a reliable associate.
            ifelse (random-float 1 >= autonomy and [color] of mysupervisor = gray) [
              set color gray
              ;; This is necessary in order to allow those associates who make autonomous decisions to empty the 'would-be-associates' list.
              ask myboss
                [set would-be-associates remove ? would-be-associates]
            ][
              ;; Otherwise, if the would-be associate makes autonomous decisions, or if its supervisor did, the would-be associate enters the organization as an autonomously-deciding participant and empties the list of would-be-associates.
              set color magenta
              ask turtle-set (but-first [would-be-associates] of myboss) [
                set myboss nobody
                setxy random world-width random world-height
              ]
              ask myboss
                [set would-be-associates []]
            ]
            ;; Both autonomously-deciding and boss-following participants take all features of organization associates.        
            set heading 0
            set organization [organization] of myboss
            set owns-solution nobody
            set owns-efficiency [owns-efficiency] of myboss
            ;; It moves to its new place and stays there.
            setxy x-destination y-destination
            set blocked? true
            ;; Patches know which organization is there. This enables bosses to know their territory.
            ask patch-here
              [set plabel [organization] of myself]
            ;; The founder records that an independent participant associated to him and that his territory expanded.
            ask myboss [
              set this-step-associated this-step-associated + 1
              set myterritory fput (patch x-destination y-destination) myterritory
            ]
          ][
            ;; If a suitable destination does not exist, would-be participants are sent away.
            set myboss nobody
            setxy random world-width random world-height
          ]
        ] ;ask
      ] ;if
    ] ;foreach
    set would-be-associates []
    set this-step-associated-list fput this-step-associated this-step-associated-list
  ] ;ask
  
  ;; Instructions for participants who are still independent.
  ask participant with [color = yellow] [
    ;; Independent participants come to the idea of founding an organization if they came close to one of them. These participants are identified by yellow color and heading zero.
    if (any? (participant-on neighbors) with [color = gray or color = magenta])
      [set heading 0]
    ;; Independent participants who are not in blocked decision processes move randomly.
    if (not blocked? and not charged?)
      [move-to patch-at (random 3 - 1) (1)]
  ]
  
  ;; Uncharged opportunities move randomly.
  ask opportunity with [not (blocked? or charged?)] [
    move-to patch-at (random 3 - 1) (1)

  ]
  ;; Unowned solutions move randomly.
  ask solution with [not (blocked? or owned?)] [
    move-to patch-at (random 3 - 1) (1)
  ]
  
  ;; Unpostponed and unpassed problems move randomly.
  ask problem with [not (blocked? or postponed? or passed?)] [
    move-to patch-at (random 3 - 1) (1)
  ]
  
  ;; Paired couples move together.
  ask patches [
    ;; Problems follow opportunities. A paired couple is marked by a brown square.
    ask opportunity-here with [charged?] [
      set pcolor black
      if (not blocked?) [
        move-to patch-at (random 3 - 1) (1)
      ]
      set pcolor brown
    ]
    ask problem-here with [postponed? and to-opportunity != nobody] [
      move-to to-opportunity
    ]
    ;; Problems follow participants. A paired couple is marked by a brown square.
    ask participant-here with [charged?] [
      if (color = yellow) [
        set pcolor black
        move-to patch-at (random 3 - 1) (1)
      ]
      set pcolor brown
    ]
    ask problem-here with [passed? and to-participant != nobody] [
      move-to to-participant
    ]
  ]
  
  





  
  


  ;; SPIN-OFFS ARE CREATED AND PLACED AT RANDOM

  ;; An organization associate clones the solution of its boss, and founds a new organization.  
  ask participant with [(color = gray or color = magenta) and owns-solution = nobody] [
    if (form-organizations? and spin-off? and sum [ability] of other participant with [organization = [organization] of myself] < ability) [
      ;; Moves to a place where no turtle is.
      let new-xcor xcor
      let new-ycor ycor
      while [any? turtles-on patch new-xcor new-ycor] [
        set new-xcor random world-width
        set new-ycor random world-height
      ]
      setxy new-xcor new-ycor
      set blocked? true
      ;; Clones the boss' solution.
      let mysolution nobody
      hatch-solution 1 [
        setxy new-xcor new-ycor
        set color red
        set blocked? true
        set efficiency [owns-efficiency] of myself
        set owned? true
        set by-participant myself        
        set mysolution self
      ]
      ;; Founds the organization.
      set color gray
      set organization who
      set myterritory fput patch-here myterritory
      ask patch-here
        [set plabel [organization] of myself]
      set owns-solution mysolution
      set label "S"
      set date-of-founding ticks
      set steps-idle 0
      set mysupervisor nobody
      set myboss nobody
      ;; Kills one solution in order to keep their number constant.
      if (replace-solutions?) [
        ifelse (any? solution with [not owned? and by-participant = nobody and not blocked?])
          [kill one-of solution with [not owned? and by-participant = nobody and not blocked?]]
          [print "WARNING: NO FREE SOLUTION IS AVAILABLE TO BE EXCHANGED WITH THE ONE DUPLICATED WHEN SPINNING-OFF"]
      ]
    ]
  ]









  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; IDLE ORGANIZATIONS ARE DISMANTLED
  
  if (form-organizations? and max-idle > 0) [
    ask participant with [color = gray and owns-solution != nobody] [
      set steps-idle steps-idle + 1
      if (steps-idle > max-idle or organization-size = max-organization-size and (ticks - date-of-founding) > max-idle) [
        ;; Stores data on the mean life of O-, R- and S-organizations.
        ;; Stores data on the mortality of organizations. Only organizations that do not die because they have grown too large are included in the statistics.
        if (label = "O") [
          set O-organizations-dismantled-this-step O-organizations-dismantled-this-step + 1
          set life-O-organizations (life-O-organizations + (ticks - date-of-founding))
          if (steps-idle > max-idle)
            [set O-mortality-list fput (ticks - date-of-founding) O-mortality-list]
        ]
        if (label = "R") [
          set R-organizations-dismantled-this-step R-organizations-dismantled-this-step + 1
          set life-R-organizations (life-R-organizations + (ticks - date-of-founding))
          if (steps-idle > max-idle)
            [set R-mortality-list fput (ticks - date-of-founding) R-mortality-list]
        ]
        if (label = "S") [
          set S-organizations-dismantled-this-step S-organizations-dismantled-this-step + 1
          set life-S-organizations (life-S-organizations + (ticks - date-of-founding))
          if (steps-idle > max-idle)
            [set S-mortality-list fput (ticks - date-of-founding) S-mortality-list]
        ]
        ;; Dismantles the organization. Heading should be different from zero.
        ask solution-here with [owned? and by-participant = myself] [
          set blocked? false
          set owned? false
          set by-participant nobody
        ]
        ;; Ask organization associates.
        ask other participant with [(color = gray or color = magenta) and organization = [organization] of myself] [
          set heading (1 + random 359)
          set color yellow
          set organization -1
          ask patch-here
            [set plabel ""]
          set owns-efficiency -1
          set mysupervisor nobody
          set myboss nobody
          set blocked? false
        ]
        ;; Finally, the organization's founder frees itself.
        set owns-solution nobody
        set heading (1 + random 359)
        set color yellow
        set organization -1
        set myterritory []
        ask patch-here
          [set plabel ""]
        set organization-size 0
        set label ""
        set date-of-founding -1
        set steps-idle -1
        set owns-efficiency -1
        set blocked? false
      ]
    ]
  ]
          
          








  
  
  ;;;;;;;;;;;;;;;;;;; SOME INDICATORS NEED GLOBAL EVALUATIONS
  
  ;; Counts the number of blocked decisions, the number of postponed problems and the number of buck-passed problems per tick.
  ;; This indicator does not appear on the screen in its averaged form.
  set cum-blocked-decisions cum-blocked-decisions + count opportunity with [blocked?]
  set blocked-decisions-per-tick cum-blocked-decisions / (ticks + 1)
  set cum-postponed-problems cum-postponed-problems + count opportunity with [charged?]
  set postponed-problems-per-tick cum-postponed-problems / (ticks + 1)
  set cum-buck-passed-problems cum-buck-passed-problems + count participant with [charged?]
  set buck-passed-problems-per-tick cum-buck-passed-problems / (ticks + 1)
  
  ;; Counts the number of independent participants with random heading, independent participants with heading 0, the number of O-organizations, R-organizations and S-organizations.
  set random-independents-list fput (count participant with [color = yellow and heading != 0]) random-independents-list
  set headed-independents-list fput (count participant with [color = yellow and heading = 0]) headed-independents-list
  set O-organizations-list fput (count participant with [color = gray and owns-solution != nobody and label = "O"]) O-organizations-list
  set R-organizations-list fput (count participant with [color = gray and owns-solution != nobody and label = "R"]) R-organizations-list
  set S-organizations-list fput (count participant with [color = gray and owns-solution != nobody and label = "S"]) S-organizations-list
  
  ;; Counts the percentages of organization founders, organization associates and independent participants.
  set percent-founders (100 * count participant with [color = gray and owns-solution != nobody] / count participant)
  set cum-percent-founders cum-percent-founders + percent-founders
  set ave-percent-founders cum-percent-founders / (ticks + 1)
  set percent-associates (100 * count participant with [color = magenta or color = gray and owns-solution = nobody] / count participant)
  set cum-percent-associates cum-percent-associates + percent-associates
  set ave-percent-associates cum-percent-associates / (ticks + 1)
  set percent-independents (100 * count participant with [color = yellow] / count participant)
  set cum-percent-independents cum-percent-independents + percent-independents
  set ave-percent-independents cum-percent-independents / (ticks + 1)
  
  ;; Counts meetings with opportunities, solutions and problems that have already been met.
  ;; Participants who are in blocked decision processes, as well as participants charged with problems, are excluded.
  ask patches with [pcolor != white] [
    ask participant-here with [not charged?] [
      set meetings-known-opp meetings-known-opp + count opportunity-here with [not blocked? and member? who [encountered] of myself]
      set meetings-opp meetings-opp + count opportunity-here with [not blocked?]
      ifelse (meetings-opp > 0)
        [set percent-known-opp 100 * meetings-known-opp / meetings-opp]
        [set percent-known-opp "N/A"]
      set meetings-known-sol meetings-known-sol + count solution-here with [not blocked? and member? who [encountered] of myself]
      set meetings-sol meetings-sol + count solution-here with [not blocked?]
      ifelse (not form-organizations? and meetings-sol > 0)
        [set percent-known-sol 100 * meetings-known-sol / meetings-sol]
        [set percent-known-sol "N/A"]
      set meetings-known-pro meetings-known-pro + count problem-here with [not blocked? and member? who [encountered] of myself]
      set meetings-pro meetings-pro + count problem-here with [not blocked?]
      ifelse (meetings-pro > 0)
        [set percent-known-pro 100 * meetings-known-pro / meetings-pro]
        [set percent-known-pro "N/A"]
      ;; Agents that had not been previously met, are added to the list.
      if (any? turtles-here with [breed != participant and not (member? who [encountered] of myself)]) [
        foreach [who] of turtles-here with [breed != participant and not (member? who [encountered] of myself)] [
          set encountered fput ? encountered
        ]
      ]
    ]
  ]

  ;; The percentage of decisions made by organization founders, organization associates, and independent participants.
  if (count participant with [color = gray and owns-solution != nobody] != 0)
    [set percent-founders-deciding 100 * (num-founders-oversights + num-founders-resolutions) / count participant with [color = gray and owns-solution != nobody]]
  set cum-percent-founders-deciding cum-percent-founders-deciding + percent-founders-deciding
  set ave-percent-founders-deciding cum-percent-founders-deciding / (ticks + 1)
  set percent-founders-deciding 0
  if (count participant with [color = magenta or color = gray and owns-solution = nobody] != 0)
    [set percent-associates-deciding 100 * (num-associates-oversights + num-associates-resolutions) / count participant with [color = magenta or color = gray and owns-solution = nobody]]
  set cum-percent-associates-deciding cum-percent-associates-deciding + percent-associates-deciding
  set ave-percent-associates-deciding cum-percent-associates-deciding / (ticks + 1)
  set percent-associates-deciding 0
  if (count participant with [color = yellow] != 0)
    [set percent-independents-deciding 100 * (num-independents-oversights + num-independents-resolutions) / count participant with [color = yellow]]
  set cum-percent-independents-deciding cum-percent-independents-deciding + percent-independents-deciding
  set ave-percent-independents-deciding cum-percent-independents-deciding / (ticks + 1)
  set percent-independents-deciding 0
  
  ;; Computes the ratios of decisions by oversight to decisions by resolution.
  if (cum-resolutions-founders > 0)
    [set ove/res-founders cum-oversights-founders / cum-resolutions-founders]
  if (cum-resolutions-associates > 0)
    [set ove/res-associates cum-oversights-associates / cum-resolutions-associates]
  if (cum-resolutions-independents > 0)
    [set ove/res-independents cum-oversights-independents / cum-resolutions-independents]
    
  ;; Computes the series of organizations founded and dismantles.
  set O-organizations-founded O-organizations-founded + count participant with [color = gray and owns-solution != nobody and label = "O" and date-of-founding = ticks]
  set O-organizations-founded-list lput O-organizations-founded O-organizations-founded-list
  set R-organizations-founded R-organizations-founded + count participant with [color = gray and owns-solution != nobody and label = "R" and date-of-founding = ticks]
  set R-organizations-founded-list lput R-organizations-founded R-organizations-founded-list
  set S-organizations-founded S-organizations-founded + count participant with [color = gray and owns-solution != nobody and label = "S" and date-of-founding = ticks]
  set S-organizations-founded-list lput S-organizations-founded S-organizations-founded-list
  set O-organizations-dismantled O-organizations-dismantled + O-organizations-dismantled-this-step
  set O-organizations-dismantled-list lput O-organizations-dismantled O-organizations-dismantled-list
  set O-organizations-dismantled-this-step 0
  set R-organizations-dismantled R-organizations-dismantled + R-organizations-dismantled-this-step
  set R-organizations-dismantled-list lput R-organizations-dismantled R-organizations-dismantled-list
  set R-organizations-dismantled-this-step 0
  set S-organizations-dismantled S-organizations-dismantled + S-organizations-dismantled-this-step
  set S-organizations-dismantled-list lput S-organizations-dismantled S-organizations-dismantled-list
  set S-organizations-dismantled-this-step 0
  
  ;; Computes the mean life of O-, R- and S-organizations.
  ifelse (form-organizations? and O-organizations-dismantled > 0)
    [set mean-life-O-organizations life-O-organizations / O-organizations-dismantled]
    [set mean-life-O-organizations "N/A"]
  ifelse (form-organizations? and R-organizations-dismantled > 0)
    [set mean-life-R-organizations life-R-organizations / R-organizations-dismantled]
    [set mean-life-O-organizations "N/A"]
  ifelse (form-organizations? and spin-off? and S-organizations-dismantled > 0)
    [set mean-life-S-organizations life-S-organizations / S-organizations-dismantled]
    [set mean-life-S-organizations "N/A"]
    
  ;; The growth rates of organizations are inserted in lists entailed by the 'growth-rate-lists-by-size' list. These lists are identified as items of the 'growth-rate-lists-by-size' list.
  set size-counter 0
  repeat max-organization-size [
    ask participant with [color = gray and owns-solution != nobody and organization-size = size-counter] [
      let thislist item size-counter growth-rate-lists-by-size  ; for some reason, it does not accept a nested instruction without 'thislist'
      set thislist fput this-step-associated thislist
      set growth-rate-lists-by-size replace-item size-counter growth-rate-lists-by-size thislist
    ]
    set size-counter size-counter + 1
  ]
  ;; Resets the counter of new associates.
  ask participant
    [set this-step-associated 0]
    
  ;; At simulation end, computes the distribution of growth rates for each organization size.
  if (stop-at > 0 and ticks = stop-at - 1) [
    set size-counter 0
    repeat max-organization-size [  ; scan organization sizes
      set growth-rate-counter 0
      repeat max-organization-size [  ; scan growth rates
        let occurrences-of-this-growth-rate occurrences (growth-rate-counter) (item (size-counter) (growth-rate-lists-by-size))  ; for some reason, it does not accept a nested instruction without these 'occurrences'.
        let thislist item size-counter growth-rate-distribution-lists-by-size  ; for some reason, it does not accept a nested instruction without 'thislist'
        set thislist lput occurrences-of-this-growth-rate thislist
        set growth-rate-distribution-lists-by-size replace-item size-counter growth-rate-distribution-lists-by-size thislist
        set growth-rate-counter growth-rate-counter + 1
      ]
      set size-counter size-counter + 1
    ]
  ]
  
  ;; Measures the size of organizations and counts organizations by size.
  set O-organization-size-list []
  set R-organization-size-list []
  set S-organization-size-list []
  ask participant with [color = gray and owns-solution != nobody and label = "O"] [
    set organization-size count participant with [organization = [organization] of myself]
    set O-organization-size-list fput organization-size O-organization-size-list
  ]
  ask participant with [color = gray and owns-solution != nobody and label = "R"] [
    set organization-size count participant with [organization = [organization] of myself]
    set R-organization-size-list fput organization-size R-organization-size-list
  ]
  ask participant with [color = gray and owns-solution != nobody and label = "S"] [
    set organization-size count participant with [organization = [organization] of myself]
    set S-organization-size-list fput organization-size S-organization-size-list
  ]
  ;; Cumulative organization size is necessary in order to compute distributions of organizations by size.
  foreach O-organization-size-list
    [set cum-O-organization-size-list fput ? cum-O-organization-size-list]
  foreach R-organization-size-list
    [set cum-R-organization-size-list fput ? cum-R-organization-size-list]
  foreach S-organization-size-list
    [set cum-S-organization-size-list fput ? cum-S-organization-size-list]
  ;; At simulation end, distributions are computed.
  if (stop-at > 0 and ticks = stop-at - 1) [
    ;; Distribution arrays are initialized.
    let O-organization-size-distribution array:from-list n-values max-organization-size [0]
    let R-organization-size-distribution array:from-list n-values max-organization-size [0]
    let S-organization-size-distribution array:from-list n-values max-organization-size [0]
    ;; Distributions of organizations by size are computed.    
    foreach cum-O-organization-size-list
      [array:set O-organization-size-distribution (? - 1) (array:item O-organization-size-distribution (? - 1) + 1)]
    foreach cum-R-organization-size-list
      [array:set R-organization-size-distribution (? - 1) (array:item R-organization-size-distribution (? - 1) + 1)]
    foreach cum-S-organization-size-list
      [array:set S-organization-size-distribution (? - 1) (array:item S-organization-size-distribution (? - 1) + 1)]
    ;; At simulation end, these lists entail distributions of organizations by size.
    set cum-O-organization-size-list array:to-list O-organization-size-distribution
    set cum-R-organization-size-list array:to-list R-organization-size-distribution
    set cum-S-organization-size-list array:to-list S-organization-size-distribution
  ]
    
  ;; How old are the organizations that are still alive at simulation end.
  if (stop-at > 0 and ticks = (stop-at - 1)) [
    ask participant with [color = gray and owns-solution != nobody and label = "O"]
      [set O-survivors-list fput (ticks - date-of-founding) O-survivors-list]
    ask participant with [color = gray and owns-solution != nobody and label = "R"]
      [set R-survivors-list fput (ticks - date-of-founding) R-survivors-list]
    ask participant with [color = gray and owns-solution != nobody and label = "S"]
      [set S-survivors-list fput (ticks - date-of-founding) S-survivors-list]
  ]




  
  ;;;;;;;;;;;;;;;;;;;;;; TICK UPDATING AND PLOTTING
        
  ;; The number of ticks is updated. Eventually, the simulation is stopped.
  tick
  
  ;; The simulation is stopped if no free patch is left.
  let free-space? false
  ask patches [
    if (not any? turtles-here)
      [set free-space? true]
  ]
  if (not free-space?) [
    print "NO FREE SPACE IS LEFT"
    stop
  ]
    
  ;; The simulation is stopped and final information is displayed.
  if (stop-at > 0 and ticks = stop-at)
    [stop]


end  ; the 'go' procedure ends here

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

















;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; If participants, choice opportunities, solutions or problems exit the organization
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; Before killing them, the agents to which they are paired must be freed.
to kill [morituri]
  if (morituri != nobody) [
    ask morituri [
      if (breed = participant) [
        ;; If the participant to be killed must be replaced, a new one is created.
        if (participants-exit? and replace-participants?) [
          ;; Move the participant to be replaced.
          let found? false
          while [not found?] [
            let newxcor random world-width
            let newycor random world-height
            if (not any? turtles-on patch newxcor newycor) [
              set found? true
              set xcor newxcor
              set ycor newycor
            ]
          ]
          ;; Clones it, but with the following differences.
          hatch 1 [
            set blocked? false
            set charged? false
            set with-problem nobody
            set encountered []
          ]
          ;; Updates the counter.
          set participants-replaced participants-replaced + 1
        ]
        ;; The participants who met this participant, they forget it.
        ask other participant [
          foreach encountered [
            if (? = [who] of myself)
              [set encountered remove ? encountered]
          ]
        ]
        ;; Finally kills it.
        die
      ]
      if (breed = opportunity) [
        ;; If the opportunity to be killed must be replaced, a new one is created.
        if (opportunities-exit? and replace-opportunities?) [
          ;; Move the opportunity to be replaced.
          let found? false
          while [not found?] [
            let newxcor random world-width
            let newycor random world-height
            if (not any? turtles-on patch newxcor newycor) [
              set found? true
              set xcor newxcor
              set ycor newycor
            ]
          ]
          ;; Clone it, but with the following differences.
          hatch 1 [ 
            set blocked? false
            set charged? false
            set with-problem nobody
          ]
          ;; Updates the counter.
          set opportunities-replaced opportunities-replaced + 1
        ]
        ;; The participants who met this opportunity, they forget it.
        ask participant [
          foreach encountered [
            if (? = [who] of myself)
              [set encountered remove ? encountered]
          ]
        ]
        ;; Finally kills it.
        die
      ]
      if (breed = solution) [
        ;; If the solution to be killed must be replaced, a new one is created.
        if (solutions-exit? and replace-solutions?) [
          ;; Move the solution to be replaced.
          let found? false
          while [not found?] [
            let newxcor random world-width
            let newycor random world-height
            if (not any? turtles-on patch newxcor newycor) [
              set found? true
              set xcor newxcor
              set ycor newycor
            ]
          ]
          ;; Clone it, but with the following differences.
          hatch 1 [ 
            set blocked? false
          ]
          ;; Updates the counter.
          set solutions-replaced solutions-replaced + 1
        ]
        ;; If the solution is to be killed in exchange for one that has been created by a spin-off, the counter is updated downwards.
        if (spin-off? and replace-solutions?)
          [set solutions-replaced solutions-replaced - 1]
        ;; The participants who met this solution, they forget it.
        ask participant [
          foreach encountered [
            if (? = [who] of myself)
              [set encountered remove ? encountered]
          ]
        ]
        ;; Finally kills it.
        die
      ]
      if (breed = problem) [
        ;; If the problem to be killed must be replaced, a new one is created.
        if (problems-exit? and replace-problems?) [
          ;; Move the problem to be replaced.
          let found? false
          while [not found?] [
            let newxcor random world-width
            let newycor random world-height
            if (not any? turtles-on patch newxcor newycor) [
              set found? true
              set xcor newxcor
              set ycor newycor
            ]
          ]
          ;; Clone it, but with the following differences.
          hatch 1 [ 
            set blocked? false
            set postponed? false
            set to-opportunity nobody
            set passed? false
            set to-participant nobody
          ]
        ;; Updates the counter.
        set problems-replaced problems-replaced + 1
        ]
        ;; The participants who met this problem, they forget it.
        ask participant [
          foreach encountered [
            if (? = [who] of myself)
              [set encountered remove ? encountered]
          ]
        ]
        ;; Finally kills it.
        die
      ]
    ]
  ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;














;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; Counts occurrences in a list ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; Counts the number of occurrences of 'x' in the list 'the-list'.
to-report occurrences [x the-list]
report reduce [
 ifelse-value (?2 = x) 
   [?1 + 1]
   [?1]
] (fput 0 the-list)
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;













;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; Wraps coordinates ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; N.B. These wrappings work under the assumption that the origin of both axes is in the bottom-left corner so all coordinates should be positive.
to-report x-wrap [coordinate]
  ifelse (coordinate >= 0)
    [report remainder coordinate world-width]
    [report world-width + remainder coordinate world-width]
end

to-report y-wrap [coordinate]
  ifelse (coordinate >= 0)
    [report remainder coordinate world-height]
    [report world-height + remainder coordinate world-height]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@#$#@#$#@
GRAPHICS-WINDOW
467
10
1925
1489
-1
-1
28.4
1
10
1
1
1
0
1
1
1
0
50
0
50
0
0
1
ticks
50.0

SLIDER
8
76
161
109
initial-opportunities
initial-opportunities
0
1000
100
1
1
NIL
HORIZONTAL

SLIDER
8
43
161
76
initial-participants
initial-participants
0
1000
500
1
1
NIL
HORIZONTAL

BUTTON
106
10
161
43
Set Up
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
84
352
161
397
problems
count problem
0
1
11

MONITOR
8
352
84
397
solutions
count solution
0
1
11

BUTTON
216
10
271
43
Go Until
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
161
10
216
43
Go Step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
314
175
467
208
min-difficulty
min-difficulty
0
10
0
0.1
1
NIL
HORIZONTAL

SLIDER
161
175
314
208
min-efficiency
min-efficiency
0
1
0
0.1
1
NIL
HORIZONTAL

SLIDER
8
175
161
208
min-ability
min-ability
0
10
0
0.1
1
NIL
HORIZONTAL

PLOT
8
712
467
842
Decisions and Flights
step
NIL
0.0
100.0
0.0
1.0
true
true
"" ""
PENS
"Oversights" 1.0 0 -13791810 true "" "plot cum-oversights"
"Resolutions" 1.0 0 -13840069 true "" "plot cum-resolutions"
"Postponements" 1.0 0 -6459832 true "" "plot cum-postponements-without-organization + cum-postponements-within-organization"
"Buck-Passings" 1.0 0 -16777216 true "" "plot cum-buck-passings-without-organization + cum-buck-passings-within-organization"

MONITOR
8
307
84
352
participants
count participant
0
1
11

MONITOR
84
307
161
352
opportunities
count opportunity
0
1
11

SLIDER
8
109
161
142
initial-solutions
initial-solutions
0
1000
100
1
1
NIL
HORIZONTAL

SLIDER
8
142
161
175
initial-problems
initial-problems
0
1000
100
1
1
NIL
HORIZONTAL

SWITCH
161
43
314
76
participants-exit?
participants-exit?
1
1
-1000

SWITCH
161
76
314
109
opportunities-exit?
opportunities-exit?
0
1
-1000

SWITCH
161
109
314
142
solutions-exit?
solutions-exit?
1
1
-1000

SWITCH
161
142
314
175
problems-exit?
problems-exit?
0
1
-1000

SLIDER
8
208
161
241
max-ability
max-ability
0
10
10
0.1
1
NIL
HORIZONTAL

SLIDER
314
208
467
241
max-difficulty
max-difficulty
0
10
10
0.1
1
NIL
HORIZONTAL

SLIDER
161
208
314
241
max-efficiency
max-efficiency
0
1
1
0.1
1
NIL
HORIZONTAL

SLIDER
8
10
106
43
stop-at
stop-at
0
5000
5000
1
1
NIL
HORIZONTAL

MONITOR
161
487
314
532
Postponed Problems
count opportunity with [charged?]
17
1
11

MONITOR
314
487
467
532
Passed Problems
count participant with [charged?]
17
1
11

MONITOR
8
442
161
487
Decisions by Resolution
cum-resolutions
17
1
11

MONITOR
8
397
161
442
Decisions by Oversight
cum-oversights
17
1
11

MONITOR
161
442
314
487
Postponements Without Org.
cum-postponements-without-organization
17
1
11

MONITOR
314
442
467
487
Buck-Passings Without Org.
cum-buck-passings-without-organization
17
1
11

MONITOR
8
487
161
532
Blocked Decisions
count opportunity with [blocked?]
17
1
11

MONITOR
8
532
161
577
% Deja-vu Opportunities
percent-known-opp
17
1
11

MONITOR
161
532
314
577
% Deja-vu Solutions
percent-known-sol\n
17
1
11

MONITOR
314
532
467
577
% Deja-vu Problems
percent-known-pro
17
1
11

MONITOR
314
622
467
667
Independents Ove / Res
ove/res-independents
17
1
11

MONITOR
161
622
314
667
Associates Ove / Res
ove/res-associates
17
1
11

MONITOR
8
622
161
667
Founders Ove / Res
ove/res-founders
17
1
11

MONITOR
314
577
467
622
% Independents Deciding
ave-percent-independents-deciding
17
1
11

MONITOR
161
577
314
622
% Associates Deciding
ave-percent-associates-deciding
17
1
11

MONITOR
8
577
161
622
 % Founders Deciding
ave-percent-founders-deciding
17
1
11

SWITCH
271
10
369
43
postpone?
postpone?
0
1
-1000

SWITCH
369
10
467
43
passbuck?
passbuck?
1
1
-1000

SWITCH
8
241
161
274
form-organizations?
form-organizations?
0
1
-1000

SWITCH
161
241
314
274
spin-off?
spin-off?
1
1
-1000

SWITCH
314
43
467
76
replace-participants?
replace-participants?
1
1
-1000

SWITCH
314
76
467
109
replace-opportunities?
replace-opportunities?
0
1
-1000

SWITCH
314
109
467
142
replace-solutions?
replace-solutions?
1
1
-1000

SWITCH
314
142
467
175
replace-problems?
replace-problems?
0
1
-1000

MONITOR
8
667
161
712
Mean Life O-Organizations
mean-life-O-organizations
17
1
11

MONITOR
161
667
314
712
Mean Life R-Organizations
mean-life-R-organizations
17
1
11

MONITOR
314
667
467
712
Mean Life S-Organizations
mean-life-S-organizations
17
1
11

SLIDER
314
241
467
274
max-idle
max-idle
0
100
30
1
1
NIL
HORIZONTAL

PLOT
8
972
467
1102
Number of Organizations
NIL
NIL
0.0
100.0
0.0
5.0
true
true
"" ""
PENS
"All Organizations" 1.0 0 -16777216 true "" "plot count participant with [color = gray and owns-solution != nobody]"
"O-organizations" 1.0 0 -13791810 true "" "plot count participant with [color = gray and owns-solution != nobody and label = \"O\"]"
"R-organizations" 1.0 0 -13840069 true "" "plot count participant with [color = gray and owns-solution != nobody and label = \"R\"]"
"S-organizations" 1.0 0 -14835848 true "" "plot count participant with [color = gray and owns-solution != nobody and label = \"S\"]"

PLOT
8
1231
467
1360
Organization Size
size
NIL
1.0
100.0
0.0
4.0
true
true
"" ""
PENS
"O-organizations" 1.0 1 -13791810 true "" "histogram cum-O-organization-size-list"
"R-organizations" 1.0 1 -13840069 true "" "histogram cum-R-organization-size-list"
"S-organizations" 1.0 1 -14835848 true "" "histogram cum-S-organization-size-list"

MONITOR
161
307
314
352
Replaced Participants
participants-replaced
17
1
11

MONITOR
314
307
467
352
Replaced Opportunities
opportunities-replaced
17
1
11

MONITOR
161
352
314
397
Replaced Solutions
solutions-replaced
17
1
11

MONITOR
314
352
467
397
Replaced Problems
problems-replaced
17
1
11

MONITOR
161
397
314
442
Postponements Within Org.
cum-postponements-within-organization
17
1
11

MONITOR
314
397
467
442
Buck-Passings Within Org.
cum-buck-passings-within-organization
17
1
11

PLOT
8
1360
467
1489
Mortality of Organizations
age
NIL
0.0
500.0
0.0
10.0
true
true
"" ""
PENS
"O-organizations" 1.0 1 -13791810 true "" "histogram O-mortality-list"
"R-organizations" 1.0 0 -13840069 true "" "histogram R-mortality-list"
"S-organizations" 1.0 0 -14835848 true "" "histogram S-mortality-list"

SLIDER
314
274
467
307
autonomy
autonomy
0
1.0
0
0.1
1
NIL
HORIZONTAL

SLIDER
161
274
314
307
span-of-control
span-of-control
1
10
2
1
1
NIL
HORIZONTAL

SLIDER
8
274
161
307
efficiency-growth-factor
efficiency-growth-factor
0
10
10
1
1
NIL
HORIZONTAL

PLOT
8
842
467
972
Number of Participants
NIL
NIL
0.0
100.0
0.0
10.0
true
true
"" ""
PENS
"All Independents" 1.0 0 -1184463 true "" "plot count participant with [color = yellow]"
"Independents Ready" 1.0 0 -7171555 true "" "plot count participant with [color = yellow and heading = 0]"
"Organization Founders" 1.0 0 -16777216 true "" "plot count participant with [color = gray and owns-solution != nobody]"
"Reliable Associates" 1.0 0 -7500403 true "" "plot count participant with [color = gray and owns-solution = nobody]"
"Autonomous Associates" 1.0 0 -5825686 true "" "plot count participant with [color = magenta]"

PLOT
8
1102
467
1231
Would-Be and Actual Associates
NIL
NIL
0.0
7.0
0.0
5.0
true
true
"" ""
PENS
"Actual Associates" 1.0 1 -10899396 true "" "histogram this-step-associated-list"
"Would-Be Associates" 1.0 1 -16777216 true "" "histogram would-be-associates-list"

@#$#@#$#@
## WHAT IS IT?

The Garbage Can Model (GCM) of organizational choice (Cohen, March and Olsen 1972) is a prominent model of organizational decision-making. It is also a unique example of a decision theory developed and expressed by means of computer simulations.

We updated and improved the GCM through subsequent steps. First, we reproduced the original GCM in an agent-based setting (Fioretti and Lomi 2008a, 2008b). Subsequently, we refined and extended the original model in order to overcome clear shortcomings as well as in order to include complementary insights (Fioretti and Lomi 2010). In particular, we added the possibility that decision makers avoid problems by passing the buck. In the original model, it was only possible to avoid problems by postponing them.

With this code, we eliminated any exogenous structure that was eventually imposed on the model in its original version. Instead, we allowed the model to generate organizations on its own. Endogenously generated organizations exhibit the same properties as those that were exogenously imposed upon the original model. Furthermore, this population of organizations reproduces all statistical regularities that have been empirically observed among real organizations.



## HOW IT WORKS

In the GCM, decision is made when the members of an organization apply a solution to an opportunity to make a decision. Note that solutions exist independently of problems, and that decisions can be made even without solving any problem. Eventually, a problem may be there to be solved, but this is not necessarily the case.

In this decision process, opportunities take the role of "garbage cans" where solutions and problems are dumped. Hence the name of the model.

The GCM can be seen as a sort of chemical reactor where 'participants' (decision-makers), 'opportunities', 'solutions' and 'problems' move randomly. Through random meetings of these elements, decisions are made. According to Cohen, March and Olsen (1972), organizations whose processes of decision-making are akin to the GCM may be called 'organized anarchies'.

We interpreted the GCM as an agent-based model where participants, opportunities, solutions and problems are four classes of agents. Participants are recognizable as stylized humans. Opportunities are denoted by orange squares. Solutions are denoted by red circles. Problems are denoted by violet triangles.

The initial number of these agents is selected by means of sliders. Agents may exit the organized anarchy and eventually be replaced depending on conditions that will be specified below. The number of simulation steps can be selected by means of a slider ranging in the 1-5000 interval.

Participants are characterized by their ability to solve  
problems. Solutions are characterized by their efficiency. Problems are characterized by their difficulty.

Ability, efficiency and difficulty take values within ranges specified by the sliders "min-ability" and "max-ability", "min-efficiency" and "max-efficiency", "min-difficulty" and "max-difficulty", respectively. Values are assigned to agents according to a uniform distribution that spans the selected range.

A decision "by resolution" takes place when at least one participant, at least one opportunity, at least one solution and at least one problem are on the same patch and the sum of the abilities of the participants on the patch, multiplied by the efficiency of the most efficient solution on the patch, is greater or equal to the sum of the difficulties of the problems on the patch. Most often, decision-making by resolution occurs when just one participant, one choice opportunity, one solution and one problem happen to be on the same patch and the ability of the participant, multiplied by the efficiency of the solution, is greater or equal to the difficulty of the problem. The patch where a decision by resolution is being made takes a green color.

However, a key feature of the GCM is that a lot of decision-making may not solve any problem at all. For instance, choice opportunities may be used as showrooms in corporate politics rather than exploited to solve problems. In these cases, decision is made "by oversight" - in the sense that problems are ignored.

Decision-making by oversight takes place when at least one participant, at least one choice opportunity and at least one solution are on the same patch. No problem needs to be there, because no problem must be solved. Thus, decision-making by oversight occurs most often when a participant, a solution and an opportunity happen to be on the same patch. The patch where a decision by oversight is being made takes a sky-blue color.

If problems find themselves on the same patch with participants, solutions and choice opportunities, but the sum of the abilities of the participants multiplied by the efficiency of the most efficient solution is less than the sum of the difficulties of the problems, all agents on the patch are blocked and no decision is made. The patch where a decision process is blocked takes a white color.

Participants can fly away from the most difficult problem involved in a blocked decision process. This is called a "flight" in the GCM. A flight may take place in two ways:

1) By postponing the most difficult problem. This was the only kind of flight envisioned in the original model (Cohen, March and Olsen 1972). It occurs if an additional opportunity walks on the patch where a decision process is blocked: the most difficult problem is bound to this opportunity, and the two start walking together. The patch where they are takes a brown color. Postponing decision-making is enabled by the switch 'postpone?'.

2) By buck-passing. This kind of flight has been introduced in our update of the original model (Fioretti and Lomi 2010). Buck-passing occurs if only one participant is on the patch where a decision process is blocked, and an additional participant walks on it: the most difficult problem is bound to the least able participant, and the two start walking together. The patch where they are takes a brown color. The possibility of buck-passing is enabled by the switch 'passbuck?'.

Once the most difficult problem left, the remaining agents may be able to make a decision, either by resolution or by oversight. Thus, flights favor decision-making.

Participants, opportunities, solutions and problems may be required to exit the organized anarchy after having been involved in a decision. This option is chosen by means of the switches "participants-exit?", "opportunities-exit?", "solutions-exit?" and "problems-exit?", respectively.

If the switch "participants-exit?" is ON, all participants on patches where decisions are made exit the organized anarchy. If the switch "opportunities-exit?" is ON, one opportunity exits from patches where a decision is made. If the switch "solutions-exit?" is ON, one solution exits from patches where a decision is made: the most efficient solution if a decision by resolution is made, or a randomly chosen solution if a decision by oversight is made. If the switch "problems-exit?" is ON, all problems on patches where a decision by resolution is made, exit the organized anarchy.

If the switch "replace-participants?" is ON, any leaving participant is immediately replaced with a participant of equal ability on a random spot. The switches "replace-opportunities?", "replace-solutions?" and "replace-problems?" have a similar meaning.

All agents are on a torus. Participants, opportunities, solutions and problems involved in a blocked decision process stay fixed. Organization members stay fixed, as well as the solution that they employ. All other agents walk randomly upwards.







## WHAT'S NEW HERE?

The basic GCM described above is only able to tell what happens in a very special kind of organization, named "organized anarchy". However, one may ask what happens if hierarchies are there.

The original GCM (Cohen, March and Olsen 1972) attempted to face this question by imposing exogenous structures on this spontaneous "organized anarchy", and indeed, interesting results were obtained. However, one may object that, in a model of organizational decision-making, hierarchies or other organizational forms should emerge endogenously.

One think of organizations as organisms that develop their own knowledge and their own routines, which they employ in the course of their lives independently of the people who become members or leave. The GCM is aligned with this interpretation, because solutions - which may represent knowledge and routines - exist independently of decision-makers. Thus, we introduced the emergence of organizations by allowing participants to capture solutions once they made a decision. Organizations, having a ready-made solution, can offer something valuable to independent participants who may wish to join.

By setting the switch 'form-organizations?' to ON, this possibility is introduced into the GCM. The model starts with no organizations. The first time a participant makes a decision, either by resolution or by oversight, he binds to himself the solution that he employed. By doing so, he founds the first organization in the model. Being an organization member, he is depicted in gray, and standing.

Subsequently, participants may happen to meet an organization if one of its members enters their neighborhood. While still yellow, participants who met an organization are depicted as standing. In order to render an imitation process, once at least one organization exists, only standing participants are able to found a new one. Standing yellow participants found an organization as soon as they make a decision. As soon as they found an organization they change their color to gray and they stop moving. They bind to themselves the solution that they employed, which they make available to independent participants if they join their organization.

If an independent participant happens to walk on the patches where an organization is, he asks to join it. The more efficient the solution employed by an organization, the more new members it can accept during one simulation step. Thus, growth rate is proportional to solution efficiency.

Once an independent participant has become an organization member, he receives the right to use the organization's solution. However, organization members must employ the organization's solution even if a more efficient solution becomes available on their patch.

When joining an organization, participants place themselves behind the founder. Organizations form hierarchy trees with a shape depending on the span-of-control - a parameter of the model. Each organization associate keeps track of his boss (the organization founder) as well as of his immediate supervisor.

Subordinates may not follow the orders issued by the organization's founder, making autonomous decisions instead. Autonomous decisions lead to slower growth. If a new member is placed on a position connected to the founder by a chain of command that is interrupted by at least one autonomous decision-maker, all other independent participants who should enter the organization during that time step are rejected. Organization members who make autonomous decisions, as well as their subordinates are depicted in purple.

Organizations exist in order to make decisions. If they do not make any decision for a time length specified by the slider 'max-idle', they die. If they reach the maximum size allowed by the size of their world, they die after 'max-idle' time steps even if they did make decisions in the meantime.

If the switch 'spin-off?' is ON, all participants involved in a decision by resolution increase their ability by an amount equal to the difficulty of the problems that they resolved. If an organization associate has an ability that is greater than the sum of the abilities of all other organization members, he can make a copy of the solution employed by his organization and found a new organization at a random location.

If the switch 'replace-solutions?' is ON when 'spin-off?' is ON, a solution is eliminated each time a spin-off occurs, so their number remains constant. Only solutions that are not owned by any organization can be eliminated.

White labels are placed near organization founders in order to distinguish which process originated their organizations: 'O' for decisions by oversight, 'R' for decisions by resolution, 'S' for spin-offs.

Organization members make decisions by oversight just like independent participants do, but they make decisions by resolution by summing up the abilities of all organization members. Nevertheless, they may also be unable to solve certain difficult problems, in which case a decision process is blocked. Similarly to independent participants, organization members may resort to flights.

However, contrary to independent participants, organization members may make use of their organization in order to arrange a flight. In the case of flights by postponement, an organization member may find an opportunity to which a difficult problem can be postponed not only among the opportunities walking on his patch, but among all opportunities walking on the patches where the organization is. In the case of flights by buck-passing, organization members may pass a difficult problem to other members of his organization as well as to independent participants walking on his patch.

## HOW TO USE IT

The following switches and sliders are available:

- stops-at: Stops the simulation after a selected number of steps. It can be overcome by pressing 'Go Until' again.

- postpone?: Allows problem postponement.

- passbuck?: Allows problem buck-passing.

- initial-participants: The number of participants with which the simulation begins.

- initial-opportunities: The number of opportunities with which the simulation begins.

- initial-solutions: The number of solutions with which the simulation begins.

- initial-problems: The number of problems with which the simulation begins.

- participants-exit?: Whether participants disappear once they have been involved in a decision process.

- opportunities-exit?: Whether opportunities disappear once they have been involved in a decision process.

- solutions-exit?: Whether solutions disappear once they have been involved in a decision process.

- problems-exit?: Whether problems disappear once they have been involved in a decision process.

-replace-participants?: Whether exiting participants should be replaced with new ones.

-replace-opportunities?: Whether exiting opportunities should be replaced with new ones.

-replace-solutions?: Whether exiting solutions should be replaced with new ones.

-replace-problems?: Whether exiting problems should be replaced with new ones.

- min-ability: The minimum ability of participants.

- max-ability: The maximum ability of participants.

- min-efficiency: The minimum efficiency of solutions.

- max-efficiency: The maximum efficiency of solutions.

- min-difficulty: The minimum difficulty of problems.

- max-difficulty: The maximum difficulty of problems.

- form-organizations?: Whether organizations arise by imitation.

- spin-off?: Whether organizations arise from spin-offs.

- max-idle: The number of steps organizations can survive without making any decision.

- efficiency-growth-factor: The factor by which the more efficient the solution adopted by an organization, the higher its average growth rate.

- span-of-control: The number of subordinates of each organization member.

- autonomy: The probability that an organization member makes autonomous decisions.

The population of participants, opportunities, solutions and problems should collectively not exceed 1000 units, unless the simulation space is enlarged. Conversely, at least a few tens of each breed are needed in order to obtain interesting outcomes.

The difficulty of problems should not be too different from the ability of participants multiplied by the efficiency of solutions. In general, maximum differences of one or two units are recommended.

The following constraints are mandatory in order to make the model work. If they are not satisfied, the simulation is stopped and an error message appears on the command center:

- Minimum ability should not be greater than maximum ability, minimum efficiency should not be grreater than maximum efficiency and minimum difficulty should not be greater than maximum difficulty;

- The switches 'participants-exit?' and 'solutions-exit?' should be OFF if 'form-solutions?' is ON.

The following configurations do not make sense. The simulation runs, but warnings appear on the command center:

- In general, it makes no sense to set the switches 'replace-participants?', 'replace-opportunities?', 'replace-solutions?' and 'replace-problems?' to ON unless the corresponding switches 'participants-exit?', 'opportunities-exit?', 'solutions-exit?' and 'problems-exit?' are ON as well;

- The exception to the above rule is when 'form-organizations?' and 'spin-off?' are ON, in which case 'replace-solutions?' ON makes sense even if 'solutions-exit?' id OFF;

- It makes no sense to set the switch 'spin-off?' at ON unless the switch 'form-organizations?' is ON as well;

- It makes no sense to set the slider 'max-idle' to values greater than zero unless 'form-organizations?' is ON. 


## THINGS TO NOTICE

The following monitors are available:

- The number of participants, opportunities, solutions and problems;

- The number of participants, opportunities, solutions and problems that have been replaced, where the number of replaced solutions is negative if spinning-off is allowed;

- The cumulative number of decisions by oversight and the cumulative number of decisions by resolution;

- The cumulative number of flights by postponement and by buck-passing, within and without organizations;

- The current number of blocked decision processes, the current number of postponed problems and the current number of passed problems;

- The percentage of opportunities, solutions and problems that participants meet, which they had already met (deja-vu);

- The percentage of organization founders, organization associates and independent participants making decisions;

- The ratio of decisions by oversight to decisions by resolution for organization founders, organization associates and independent participants;

- The mean life of organizations founded by means of a decision by oversight, by means of a decision by resolution and by means of a spin-off.

The following graphs are drawn:

- The dynamics of the number of decisions by oversight, decisions by resolution, flights by postponement and flights by buck-passing;

- The dynamics of participants split into independent participants, independent participants ready to found an organization, organization founders, organization associates implementing the boss' policy and organization associates not implementing the boss' policy;

- The dynamics of the number of organizations founded by means of a decision by oversight, by means of a decision by resolution and by means of a spin-off;

- The distribution of would-be associates per organization per time step and the distribution of participants who actually joined per organization per time step, cumulated over the whole simulation;

- The size distributions of organizations founded by resolutions, oversights and spin-offs, cumulated over the whole simulation;

- The distibution of organizational mortality by age.

Our GCM with endogenous formation of organizations reproduces the main properties of the original GCM (Fioretti and Lomi 2010): 

1) Most decisions are made by oversight, only a few decisions are made by resolution. This can be readily seen by comparing the monitors 'Decisions by Oversight' and 'Decisions by Resolution'.

2) Participants meet the same problems again and again. This is highlighted by the monitor 'Deja-vu Problems'. The monitors 'Deja-vu Opportunities' and 'Deja-vu Solutions' highlight similar properties for opportunities and solutions, respectively.

3) At the highest hierarchical levels, decisions by resolution are most rare. This can be seen by comparing the monitors 'Founders Ove / Res', 'Associates Ove / Res' and 'Independents Ove / Res'.

Property (2) is a real emergent property of the model, whereas in Cohen, March and Olsen (1972) it was imposed on the GCM. Property (3), which involves hierarchies, is proven on the endogenously generated organizations.

Our organizations follow the growth rules known as "Gibrat's Law":

4) Organizations pick up a growth rate at birth, which they keep throughout their lives independently of size. Indeed, our organizations attract independent participants with a probability that is proportional to organization size as well as to the efficiency of an organization's solution.

Furthermore, the dynamics of our population of organizations is coherent with the following empirical stylized facts:

5) The proliferation of organizations follows an S-shaped curve.

6) The distribution of organization size is skewed to the left, i.e., typically many small organizations coexist with a few large ones.

7) For each organization size, the distribution of growth rates is a decreasing exponential law.

8) The distribution of the standard deviation of growth rates with organization size follows a power law.

9) The distribution of organizations' mortality by age is skewed to the left, i.e., young organizations have the highest probability to die.



## THINGS TO TRY

Check the above properties with different parameter values. A thorough sensitivity analysis is still waiting to be carried out.

## EXTENDING THE MODEL

In this version, organizations dissolve as soon as they reach the maximum size allowed by the artificial world where they live. This introduces distortions. Either a different growth dynamics should be envisioned, or the model should simply sto as soon as one organization reaches the maximum size allowed.

## NETLOGO FEATURES

In order to make agents communicate through several nested loops, patches are eventually used to store information. Furthermore, rather tricky math is used in order to compute supervisors' positions, to wrap the coordinates of new organization members around the torus and to compute maximum organization size given world size.

The model is parametrized to the world size so this can be changed without impairing its functioning. However, it is essential that the origin of coordinates is on the lower left corner in order for wrappings to work.




## CREDITS AND REFERENCES

Cohen M.D., March J.G. and Olsen J.P. (1972) A Garbage Can Model of Organizational Choice. Administrative Science Quarterly, 17 (1): 1-25.

Fioretti G. and Lomi A. (2008a) An Agent-Based Representation of the Garbage Can Model of Organizational Choice. Journal of Artificial Societies and Social Simulation, 11 (1). 

Fioretti G. and Lomi A. (2008b) The Garbage Can Model of Organizational Choice: An agent-based reconstruction. Simulation Modelling Practice and Theory, 16 (2): 192-217.

Fioretti G. and Lomi A. (2010) Passing the Buck in the Garbage Can Model of Organizational Choice. Working Paper.

This model was built by:  
Guido Fioretti  
University of Bologna  
Department of Management Science

## HOW TO CITE

Fioretti G. and Lomi A. (2012) Garbage Can Ecologies: An Agent-Based Exploration. In A. Lomi and R. Harrison (Eds.), The Garbage Can Model of Organizational Choice: Looking Forward at Forty. Bingley (UK): Emerald Group Publishing, Research in the Sociology of Organizations, Volume 36.

## COPYRIGHT NOTICE

This software is distributed under the GNU Public Licence (GPL).
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

ant
true
0
Polygon -7500403 true true 136 61 129 46 144 30 119 45 124 60 114 82 97 37 132 10 93 36 111 84 127 105 172 105 189 84 208 35 171 11 202 35 204 37 186 82 177 60 180 44 159 32 170 44 165 60
Polygon -7500403 true true 150 95 135 103 139 117 125 149 137 180 135 196 150 204 166 195 161 180 174 150 158 116 164 102
Polygon -7500403 true true 149 186 128 197 114 232 134 270 149 282 166 270 185 232 171 195 149 186
Polygon -7500403 true true 225 66 230 107 159 122 161 127 234 111 236 106
Polygon -7500403 true true 78 58 99 116 139 123 137 128 95 119
Polygon -7500403 true true 48 103 90 147 129 147 130 151 86 151
Polygon -7500403 true true 65 224 92 171 134 160 135 164 95 175
Polygon -7500403 true true 235 222 210 170 163 162 161 166 208 174
Polygon -7500403 true true 249 107 211 147 168 147 168 150 213 150

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

bee
true
0
Polygon -1184463 true false 151 152 137 77 105 67 89 67 66 74 48 85 36 100 24 116 14 134 0 151 15 167 22 182 40 206 58 220 82 226 105 226 134 222
Polygon -16777216 true false 151 150 149 128 149 114 155 98 178 80 197 80 217 81 233 95 242 117 246 141 247 151 245 177 234 195 218 207 206 211 184 211 161 204 151 189 148 171
Polygon -7500403 true true 246 151 241 119 240 96 250 81 261 78 275 87 282 103 277 115 287 121 299 150 286 180 277 189 283 197 281 210 270 222 256 222 243 212 242 192
Polygon -16777216 true false 115 70 129 74 128 223 114 224
Polygon -16777216 true false 89 67 74 71 74 224 89 225 89 67
Polygon -16777216 true false 43 91 31 106 31 195 45 211
Line -1 false 200 144 213 70
Line -1 false 213 70 213 45
Line -1 false 214 45 203 26
Line -1 false 204 26 185 22
Line -1 false 185 22 170 25
Line -1 false 169 26 159 37
Line -1 false 159 37 156 55
Line -1 false 157 55 199 143
Line -1 false 200 141 162 227
Line -1 false 162 227 163 241
Line -1 false 163 241 171 249
Line -1 false 171 249 190 254
Line -1 false 192 253 203 248
Line -1 false 205 249 218 235
Line -1 false 218 235 200 144

bird1
false
0
Polygon -7500403 true true 2 6 2 39 270 298 297 298 299 271 187 160 279 75 276 22 100 67 31 0

bird2
false
0
Polygon -7500403 true true 2 4 33 4 298 270 298 298 272 298 155 184 117 289 61 295 61 105 0 43

boat1
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6459832 true false 150 32 157 162
Polygon -13345367 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7500403 true true 158 33 230 157 182 150 169 151 157 156
Polygon -7500403 true true 149 55 88 143 103 139 111 136 117 139 126 145 130 147 139 147 146 146 149 55

boat2
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6459832 true false 150 32 157 162
Polygon -13345367 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7500403 true true 157 54 175 79 174 96 185 102 178 112 194 124 196 131 190 139 192 146 211 151 216 154 157 154
Polygon -7500403 true true 150 74 146 91 139 99 143 114 141 123 137 126 131 129 132 139 142 136 126 142 119 147 148 147

boat3
false
0
Polygon -1 true false 63 162 90 207 223 207 290 162
Rectangle -6459832 true false 150 32 157 162
Polygon -13345367 true false 150 34 131 49 145 47 147 48 149 49
Polygon -7500403 true true 158 37 172 45 188 59 202 79 217 109 220 130 218 147 204 156 158 156 161 142 170 123 170 102 169 88 165 62
Polygon -7500403 true true 149 66 142 78 139 96 141 111 146 139 148 147 110 147 113 131 118 106 126 71

box
true
0
Rectangle -7500403 true true 46 47 255 255

butterfly1
true
0
Polygon -16777216 true false 151 76 138 91 138 284 150 296 162 286 162 91
Polygon -7500403 true true 164 106 184 79 205 61 236 48 259 53 279 86 287 119 289 158 278 177 256 182 164 181
Polygon -7500403 true true 136 110 119 82 110 71 85 61 59 48 36 56 17 88 6 115 2 147 15 178 134 178
Polygon -7500403 true true 46 181 28 227 50 255 77 273 112 283 135 274 135 180
Polygon -7500403 true true 165 185 254 184 272 224 255 251 236 267 191 283 164 276
Line -7500403 true 167 47 159 82
Line -7500403 true 136 47 145 81
Circle -7500403 true true 165 45 8
Circle -7500403 true true 134 45 6
Circle -7500403 true true 133 44 7
Circle -7500403 true true 133 43 8

circle
false
0
Circle -7500403 true true 34 34 230

opportunity
true
0
Rectangle -955883 true false 45 45 255 255

participant
true
4
Circle -1184463 true true 125 5 63
Rectangle -1184463 true true 120 90 195 225
Polygon -1184463 true true 120 90 30 150 45 180 113 139 120 140
Polygon -1184463 true true 195 90 285 150 270 180 185 137
Polygon -1184463 true true 120 225 100 309 138 309 150 195
Polygon -1184463 true true 165 195 180 308 212 308 180 180
Rectangle -1184463 true true 150 30 165 120

person
false
0
Circle -7500403 true true 155 20 63
Rectangle -7500403 true true 158 79 217 164
Polygon -7500403 true true 158 81 110 129 131 143 158 109 165 110
Polygon -7500403 true true 216 83 267 123 248 143 215 107
Polygon -7500403 true true 167 163 145 234 183 234 183 163
Polygon -7500403 true true 195 163 195 233 227 233 206 159

problem
true
0
Polygon -8630108 true false 149 1 31 239 271 239

solution
true
0
Circle -2674135 true false 75 73 151
Circle -2674135 true false 11 12 273

spacecraft
true
0
Polygon -7500403 true true 150 0 180 135 255 255 225 240 150 180 75 240 45 255 120 135

thin-arrow
true
0
Polygon -7500403 true true 150 0 0 150 120 150 120 293 180 293 180 150 300 150

truck-down
false
0
Polygon -7500403 true true 225 30 225 270 120 270 105 210 60 180 45 30 105 60 105 30
Polygon -8630108 true false 195 75 195 120 240 120 240 75
Polygon -8630108 true false 195 225 195 180 240 180 240 225

truck-left
false
0
Polygon -7500403 true true 120 135 225 135 225 210 75 210 75 165 105 165
Polygon -8630108 true false 90 210 105 225 120 210
Polygon -8630108 true false 180 210 195 225 210 210

truck-right
false
0
Polygon -7500403 true true 180 135 75 135 75 210 225 210 225 165 195 165
Polygon -8630108 true false 210 210 195 225 180 210
Polygon -8630108 true false 120 210 105 225 90 210

turtle
true
0
Polygon -7500403 true true 138 75 162 75 165 105 225 105 225 142 195 135 195 187 225 195 225 225 195 217 195 202 105 202 105 217 75 225 75 195 105 187 105 135 75 142 75 105 135 105

wolf-left
false
3
Polygon -6459832 true true 117 97 91 74 66 74 60 85 36 85 38 92 44 97 62 97 81 117 84 134 92 147 109 152 136 144 174 144 174 103 143 103 134 97
Polygon -6459832 true true 87 80 79 55 76 79
Polygon -6459832 true true 81 75 70 58 73 82
Polygon -6459832 true true 99 131 76 152 76 163 96 182 104 182 109 173 102 167 99 173 87 159 104 140
Polygon -6459832 true true 107 138 107 186 98 190 99 196 112 196 115 190
Polygon -6459832 true true 116 140 114 189 105 137
Rectangle -6459832 true true 109 150 114 192
Rectangle -6459832 true true 111 143 116 191
Polygon -6459832 true true 168 106 184 98 205 98 218 115 218 137 186 164 196 176 195 194 178 195 178 183 188 183 169 164 173 144
Polygon -6459832 true true 207 140 200 163 206 175 207 192 193 189 192 177 198 176 185 150
Polygon -6459832 true true 214 134 203 168 192 148
Polygon -6459832 true true 204 151 203 176 193 148
Polygon -6459832 true true 207 103 221 98 236 101 243 115 243 128 256 142 239 143 233 133 225 115 214 114

wolf-right
false
3
Polygon -6459832 true true 170 127 200 93 231 93 237 103 262 103 261 113 253 119 231 119 215 143 213 160 208 173 189 187 169 190 154 190 126 180 106 171 72 171 73 126 122 126 144 123 159 123
Polygon -6459832 true true 201 99 214 69 215 99
Polygon -6459832 true true 207 98 223 71 220 101
Polygon -6459832 true true 184 172 189 234 203 238 203 246 187 247 180 239 171 180
Polygon -6459832 true true 197 174 204 220 218 224 219 234 201 232 195 225 179 179
Polygon -6459832 true true 78 167 95 187 95 208 79 220 92 234 98 235 100 249 81 246 76 241 61 212 65 195 52 170 45 150 44 128 55 121 69 121 81 135
Polygon -6459832 true true 48 143 58 141
Polygon -6459832 true true 46 136 68 137
Polygon -6459832 true true 45 129 35 142 37 159 53 192 47 210 62 238 80 237
Line -16777216 false 74 237 59 213
Line -16777216 false 59 213 59 212
Line -16777216 false 58 211 67 192
Polygon -6459832 true true 38 138 66 149
Polygon -6459832 true true 46 128 33 120 21 118 11 123 3 138 5 160 13 178 9 192 0 199 20 196 25 179 24 161 25 148 45 140
Polygon -6459832 true true 67 122 96 126 63 144

@#$#@#$#@
NetLogo 5.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="O-organizations-list" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>O-organizations-list</metric>
    <enumeratedValueSet variable="stop-at">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="postpone?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="passbuck?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-participants">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="participants-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-participants?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-opportunities">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="opportunities-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-opportunities?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-solutions">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="solutions-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-solutions?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-problems">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="problems-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-problems?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-ability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ability">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-efficiency">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-efficiency">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-difficulty">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-difficulty">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="form-organizations?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spin-off?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-idle">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency-growth-factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="span-of-control">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autonomy">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R-organizations-list" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>R-organizations-list</metric>
    <enumeratedValueSet variable="stop-at">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="postpone?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="passbuck?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-participants">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="participants-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-participants?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-opportunities">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="opportunities-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-opportunities?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-solutions">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="solutions-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-solutions?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-problems">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="problems-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-problems?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-ability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ability">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-efficiency">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-efficiency">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-difficulty">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-difficulty">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="form-organizations?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spin-off?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-idle">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency-growth-factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="span-of-control">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autonomy">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="indicators" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>opportunities-replaced</metric>
    <metric>problems-replaced</metric>
    <metric>cum-oversights</metric>
    <metric>cum-resolutions</metric>
    <metric>cum-postponements-within-organization</metric>
    <metric>cum-postponements-without-organization</metric>
    <metric>blocked-decisions-per-tick</metric>
    <metric>postponed-problems-per-tick</metric>
    <metric>percent-known-opp</metric>
    <metric>percent-known-pro</metric>
    <metric>ave-percent-founders</metric>
    <metric>ave-percent-associates</metric>
    <metric>ave-percent-independents</metric>
    <metric>ave-percent-founders-deciding</metric>
    <metric>ave-percent-associates-deciding</metric>
    <metric>ave-percent-independents-deciding</metric>
    <metric>ove/res-founders</metric>
    <metric>ove/res-associates</metric>
    <metric>ove/res-independents</metric>
    <metric>O-organizations-founded</metric>
    <metric>O-organizations-dismantled</metric>
    <metric>R-organizations-founded</metric>
    <metric>R-organizations-dismantled</metric>
    <metric>mean-life-O-organizations</metric>
    <metric>mean-life-R-organizations</metric>
    <enumeratedValueSet variable="stop-at">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="postpone?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="passbuck?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-participants">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="participants-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-participants?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-opportunities">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="opportunities-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-opportunities?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-solutions">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="solutions-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-solutions?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-problems">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="problems-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-problems?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-ability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ability">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-efficiency">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-efficiency">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-difficulty">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-difficulty">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="form-organizations?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spin-off?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-idle">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency-growth-factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="span-of-control">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autonomy">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="O-organizations-size-distribution" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>cum-O-organization-size-list</metric>
    <enumeratedValueSet variable="stop-at">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="postpone?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="passbuck?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-participants">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="participants-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-participants?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-opportunities">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="opportunities-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-opportunities?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-solutions">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="solutions-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-solutions?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-problems">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="problems-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-problems?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-ability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ability">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-efficiency">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-efficiency">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-difficulty">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-difficulty">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="form-organizations?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spin-off?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-idle">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency-growth-factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="span-of-control">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autonomy">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="mortality-list" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>mortality-list</metric>
    <enumeratedValueSet variable="stop-at">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="postpone?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="passbuck?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-participants">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="participants-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-participants?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-opportunities">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="opportunities-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-opportunities?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-solutions">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="solutions-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-solutions?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-problems">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="problems-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-problems?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-ability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ability">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-efficiency">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-efficiency">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-difficulty">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-difficulty">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="form-organizations?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spin-off?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-idle">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency-growth-factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="span-of-control">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autonomy">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="growth-rate-distribution-list" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>item 0 growth-rate-distribution-lists-by-size</metric>
    <metric>item 1 growth-rate-distribution-lists-by-size</metric>
    <metric>item 2 growth-rate-distribution-lists-by-size</metric>
    <metric>item 3 growth-rate-distribution-lists-by-size</metric>
    <metric>item 4 growth-rate-distribution-lists-by-size</metric>
    <metric>item 5 growth-rate-distribution-lists-by-size</metric>
    <metric>item 6 growth-rate-distribution-lists-by-size</metric>
    <metric>item 7 growth-rate-distribution-lists-by-size</metric>
    <metric>item 8 growth-rate-distribution-lists-by-size</metric>
    <metric>item 9 growth-rate-distribution-lists-by-size</metric>
    <metric>item 10 growth-rate-distribution-lists-by-size</metric>
    <metric>item 11 growth-rate-distribution-lists-by-size</metric>
    <metric>item 12 growth-rate-distribution-lists-by-size</metric>
    <metric>item 13 growth-rate-distribution-lists-by-size</metric>
    <metric>item 14 growth-rate-distribution-lists-by-size</metric>
    <metric>item 15 growth-rate-distribution-lists-by-size</metric>
    <metric>item 16 growth-rate-distribution-lists-by-size</metric>
    <metric>item 17 growth-rate-distribution-lists-by-size</metric>
    <metric>item 18 growth-rate-distribution-lists-by-size</metric>
    <metric>item 19 growth-rate-distribution-lists-by-size</metric>
    <enumeratedValueSet variable="stop-at">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="postpone?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="passbuck?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-participants">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="participants-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-participants?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-opportunities">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="opportunities-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-opportunities?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-solutions">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="solutions-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-solutions?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-problems">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="problems-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-problems?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-ability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ability">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-efficiency">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-efficiency">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-difficulty">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-difficulty">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="form-organizations?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spin-off?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-idle">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="span-of-control">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autonomy">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency-growth-factor">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R-organizations-size-distribution" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>cum-R-organization-size-list</metric>
    <enumeratedValueSet variable="stop-at">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="postpone?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="passbuck?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-participants">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="participants-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-participants?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-opportunities">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="opportunities-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-opportunities?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-solutions">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="solutions-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-solutions?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-problems">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="problems-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-problems?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-ability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ability">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-efficiency">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-efficiency">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-difficulty">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-difficulty">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="form-organizations?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spin-off?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-idle">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency-growth-factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="span-of-control">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autonomy">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="O-mortality-list" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>O-mortality-list</metric>
    <enumeratedValueSet variable="stop-at">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="postpone?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="passbuck?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-participants">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="participants-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-participants?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-opportunities">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="opportunities-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-opportunities?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-solutions">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="solutions-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-solutions?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-problems">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="problems-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-problems?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-ability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ability">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-efficiency">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-efficiency">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-difficulty">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-difficulty">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="form-organizations?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spin-off?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-idle">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency-growth-factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="span-of-control">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autonomy">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="O-organizations-founded" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>O-organizations-founded-list</metric>
    <enumeratedValueSet variable="stop-at">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="postpone?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="passbuck?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-participants">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="participants-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-participants?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-opportunities">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="opportunities-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-opportunities?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-solutions">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="solutions-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-solutions?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-problems">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="problems-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-problems?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-ability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ability">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-efficiency">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-efficiency">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-difficulty">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-difficulty">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="form-organizations?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spin-off?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-idle">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency-growth-factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="span-of-control">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autonomy">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R-mortality-list" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>R-mortality-list</metric>
    <enumeratedValueSet variable="stop-at">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="postpone?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="passbuck?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-participants">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="participants-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-participants?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-opportunities">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="opportunities-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-opportunities?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-solutions">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="solutions-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-solutions?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-problems">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="problems-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-problems?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-ability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ability">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-efficiency">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-efficiency">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-difficulty">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-difficulty">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="form-organizations?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spin-off?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-idle">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency-growth-factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="span-of-control">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autonomy">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R-organizations-founded" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>R-organizations-founded-list</metric>
    <enumeratedValueSet variable="stop-at">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="postpone?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="passbuck?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-participants">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="participants-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-participants?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-opportunities">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="opportunities-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-opportunities?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-solutions">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="solutions-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-solutions?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-problems">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="problems-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-problems?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-ability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ability">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-efficiency">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-efficiency">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-difficulty">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-difficulty">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="form-organizations?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spin-off?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-idle">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency-growth-factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="span-of-control">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autonomy">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="R-organizations-dismantled" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>R-organizations-dismantled-list</metric>
    <enumeratedValueSet variable="stop-at">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="postpone?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="passbuck?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-participants">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="participants-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-participants?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-opportunities">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="opportunities-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-opportunities?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-solutions">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="solutions-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-solutions?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-problems">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="problems-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-problems?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-ability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ability">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-efficiency">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-efficiency">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-difficulty">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-difficulty">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="form-organizations?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spin-off?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-idle">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency-growth-factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="span-of-control">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autonomy">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="O-organizations-dismantled" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>O-organizations-dismantled-list</metric>
    <enumeratedValueSet variable="stop-at">
      <value value="5000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="postpone?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="passbuck?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-participants">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="participants-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-participants?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-opportunities">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="opportunities-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-opportunities?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-solutions">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="solutions-exit?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-solutions?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-problems">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="problems-exit?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="replace-problems?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-ability">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-ability">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-efficiency">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-efficiency">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="min-difficulty">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-difficulty">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="form-organizations?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="spin-off?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-idle">
      <value value="30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="efficiency-growth-factor">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="span-of-control">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="autonomy">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
